@font-face {
  font-family: "Glyphicons Halflings";
  src: url("components/bootstrap/fonts/glyphicons-halflings-regular.eot");
  src: url("components/bootstrap/fonts/glyphicons-halflings-regular.eot?#iefix") format("embedded-opentype"), url("components/bootstrap/fonts/glyphicons-halflings-regular.woff2") format("woff2"), url("components/bootstrap/fonts/glyphicons-halflings-regular.woff") format("woff"), url("components/bootstrap/fonts/glyphicons-halflings-regular.ttf") format("truetype"), url("components/bootstrap/fonts/glyphicons-halflings-regular.svg") format("svg");
}
/* line 24, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon {
  position: relative;
  top: 1px;
  display: inline-block;
  font-family: "Glyphicons Halflings";
  font-style: normal;
  font-weight: 400;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
/* line 37, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-asterisk:before {
  content: "\002a";
}
/* line 38, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-plus:before {
  content: "\002b";
}
/* line 40, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-euro:before,
.glyphicon-eur:before {
  content: "\20ac";
}
/* line 41, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-minus:before {
  content: "\2212";
}
/* line 42, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-cloud:before {
  content: "\2601";
}
/* line 43, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-envelope:before {
  content: "\2709";
}
/* line 44, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-pencil:before {
  content: "\270f";
}
/* line 45, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-glass:before {
  content: "\e001";
}
/* line 46, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-music:before {
  content: "\e002";
}
/* line 47, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-search:before {
  content: "\e003";
}
/* line 48, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-heart:before {
  content: "\e005";
}
/* line 49, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-star:before {
  content: "\e006";
}
/* line 50, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-star-empty:before {
  content: "\e007";
}
/* line 51, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-user:before {
  content: "\e008";
}
/* line 52, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-film:before {
  content: "\e009";
}
/* line 53, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-th-large:before {
  content: "\e010";
}
/* line 54, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-th:before {
  content: "\e011";
}
/* line 55, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-th-list:before {
  content: "\e012";
}
/* line 56, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-ok:before {
  content: "\e013";
}
/* line 57, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-remove:before {
  content: "\e014";
}
/* line 58, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-zoom-in:before {
  content: "\e015";
}
/* line 59, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-zoom-out:before {
  content: "\e016";
}
/* line 60, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-off:before {
  content: "\e017";
}
/* line 61, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-signal:before {
  content: "\e018";
}
/* line 62, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-cog:before {
  content: "\e019";
}
/* line 63, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-trash:before {
  content: "\e020";
}
/* line 64, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-home:before {
  content: "\e021";
}
/* line 65, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-file:before {
  content: "\e022";
}
/* line 66, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-time:before {
  content: "\e023";
}
/* line 67, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-road:before {
  content: "\e024";
}
/* line 68, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-download-alt:before {
  content: "\e025";
}
/* line 69, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-download:before {
  content: "\e026";
}
/* line 70, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-upload:before {
  content: "\e027";
}
/* line 71, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-inbox:before {
  content: "\e028";
}
/* line 72, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-play-circle:before {
  content: "\e029";
}
/* line 73, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-repeat:before {
  content: "\e030";
}
/* line 74, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-refresh:before {
  content: "\e031";
}
/* line 75, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-list-alt:before {
  content: "\e032";
}
/* line 76, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-lock:before {
  content: "\e033";
}
/* line 77, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-flag:before {
  content: "\e034";
}
/* line 78, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-headphones:before {
  content: "\e035";
}
/* line 79, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-volume-off:before {
  content: "\e036";
}
/* line 80, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-volume-down:before {
  content: "\e037";
}
/* line 81, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-volume-up:before {
  content: "\e038";
}
/* line 82, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-qrcode:before {
  content: "\e039";
}
/* line 83, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-barcode:before {
  content: "\e040";
}
/* line 84, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-tag:before {
  content: "\e041";
}
/* line 85, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-tags:before {
  content: "\e042";
}
/* line 86, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-book:before {
  content: "\e043";
}
/* line 87, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-bookmark:before {
  content: "\e044";
}
/* line 88, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-print:before {
  content: "\e045";
}
/* line 89, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-camera:before {
  content: "\e046";
}
/* line 90, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-font:before {
  content: "\e047";
}
/* line 91, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-bold:before {
  content: "\e048";
}
/* line 92, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-italic:before {
  content: "\e049";
}
/* line 93, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-text-height:before {
  content: "\e050";
}
/* line 94, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-text-width:before {
  content: "\e051";
}
/* line 95, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-align-left:before {
  content: "\e052";
}
/* line 96, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-align-center:before {
  content: "\e053";
}
/* line 97, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-align-right:before {
  content: "\e054";
}
/* line 98, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-align-justify:before {
  content: "\e055";
}
/* line 99, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-list:before {
  content: "\e056";
}
/* line 100, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-indent-left:before {
  content: "\e057";
}
/* line 101, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-indent-right:before {
  content: "\e058";
}
/* line 102, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-facetime-video:before {
  content: "\e059";
}
/* line 103, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-picture:before {
  content: "\e060";
}
/* line 104, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-map-marker:before {
  content: "\e062";
}
/* line 105, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-adjust:before {
  content: "\e063";
}
/* line 106, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-tint:before {
  content: "\e064";
}
/* line 107, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-edit:before {
  content: "\e065";
}
/* line 108, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-share:before {
  content: "\e066";
}
/* line 109, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-check:before {
  content: "\e067";
}
/* line 110, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-move:before {
  content: "\e068";
}
/* line 111, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-step-backward:before {
  content: "\e069";
}
/* line 112, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-fast-backward:before {
  content: "\e070";
}
/* line 113, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-backward:before {
  content: "\e071";
}
/* line 114, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-play:before {
  content: "\e072";
}
/* line 115, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-pause:before {
  content: "\e073";
}
/* line 116, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-stop:before {
  content: "\e074";
}
/* line 117, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-forward:before {
  content: "\e075";
}
/* line 118, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-fast-forward:before {
  content: "\e076";
}
/* line 119, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-step-forward:before {
  content: "\e077";
}
/* line 120, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-eject:before {
  content: "\e078";
}
/* line 121, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-chevron-left:before {
  content: "\e079";
}
/* line 122, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-chevron-right:before {
  content: "\e080";
}
/* line 123, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-plus-sign:before {
  content: "\e081";
}
/* line 124, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-minus-sign:before {
  content: "\e082";
}
/* line 125, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-remove-sign:before {
  content: "\e083";
}
/* line 126, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-ok-sign:before {
  content: "\e084";
}
/* line 127, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-question-sign:before {
  content: "\e085";
}
/* line 128, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-info-sign:before {
  content: "\e086";
}
/* line 129, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-screenshot:before {
  content: "\e087";
}
/* line 130, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-remove-circle:before {
  content: "\e088";
}
/* line 131, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-ok-circle:before {
  content: "\e089";
}
/* line 132, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-ban-circle:before {
  content: "\e090";
}
/* line 133, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-arrow-left:before {
  content: "\e091";
}
/* line 134, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-arrow-right:before {
  content: "\e092";
}
/* line 135, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-arrow-up:before {
  content: "\e093";
}
/* line 136, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-arrow-down:before {
  content: "\e094";
}
/* line 137, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-share-alt:before {
  content: "\e095";
}
/* line 138, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-resize-full:before {
  content: "\e096";
}
/* line 139, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-resize-small:before {
  content: "\e097";
}
/* line 140, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-exclamation-sign:before {
  content: "\e101";
}
/* line 141, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-gift:before {
  content: "\e102";
}
/* line 142, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-leaf:before {
  content: "\e103";
}
/* line 143, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-fire:before {
  content: "\e104";
}
/* line 144, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-eye-open:before {
  content: "\e105";
}
/* line 145, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-eye-close:before {
  content: "\e106";
}
/* line 146, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-warning-sign:before {
  content: "\e107";
}
/* line 147, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-plane:before {
  content: "\e108";
}
/* line 148, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-calendar:before {
  content: "\e109";
}
/* line 149, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-random:before {
  content: "\e110";
}
/* line 150, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-comment:before {
  content: "\e111";
}
/* line 151, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-magnet:before {
  content: "\e112";
}
/* line 152, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-chevron-up:before {
  content: "\e113";
}
/* line 153, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-chevron-down:before {
  content: "\e114";
}
/* line 154, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-retweet:before {
  content: "\e115";
}
/* line 155, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-shopping-cart:before {
  content: "\e116";
}
/* line 156, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-folder-close:before {
  content: "\e117";
}
/* line 157, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-folder-open:before {
  content: "\e118";
}
/* line 158, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-resize-vertical:before {
  content: "\e119";
}
/* line 159, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-resize-horizontal:before {
  content: "\e120";
}
/* line 160, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-hdd:before {
  content: "\e121";
}
/* line 161, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-bullhorn:before {
  content: "\e122";
}
/* line 162, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-bell:before {
  content: "\e123";
}
/* line 163, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-certificate:before {
  content: "\e124";
}
/* line 164, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-thumbs-up:before {
  content: "\e125";
}
/* line 165, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-thumbs-down:before {
  content: "\e126";
}
/* line 166, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-hand-right:before {
  content: "\e127";
}
/* line 167, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-hand-left:before {
  content: "\e128";
}
/* line 168, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-hand-up:before {
  content: "\e129";
}
/* line 169, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-hand-down:before {
  content: "\e130";
}
/* line 170, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-circle-arrow-right:before {
  content: "\e131";
}
/* line 171, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-circle-arrow-left:before {
  content: "\e132";
}
/* line 172, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-circle-arrow-up:before {
  content: "\e133";
}
/* line 173, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-circle-arrow-down:before {
  content: "\e134";
}
/* line 174, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-globe:before {
  content: "\e135";
}
/* line 175, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-wrench:before {
  content: "\e136";
}
/* line 176, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-tasks:before {
  content: "\e137";
}
/* line 177, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-filter:before {
  content: "\e138";
}
/* line 178, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-briefcase:before {
  content: "\e139";
}
/* line 179, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-fullscreen:before {
  content: "\e140";
}
/* line 180, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-dashboard:before {
  content: "\e141";
}
/* line 181, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-paperclip:before {
  content: "\e142";
}
/* line 182, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-heart-empty:before {
  content: "\e143";
}
/* line 183, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-link:before {
  content: "\e144";
}
/* line 184, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-phone:before {
  content: "\e145";
}
/* line 185, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-pushpin:before {
  content: "\e146";
}
/* line 186, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-usd:before {
  content: "\e148";
}
/* line 187, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-gbp:before {
  content: "\e149";
}
/* line 188, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-sort:before {
  content: "\e150";
}
/* line 189, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-sort-by-alphabet:before {
  content: "\e151";
}
/* line 190, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-sort-by-alphabet-alt:before {
  content: "\e152";
}
/* line 191, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-sort-by-order:before {
  content: "\e153";
}
/* line 192, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-sort-by-order-alt:before {
  content: "\e154";
}
/* line 193, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-sort-by-attributes:before {
  content: "\e155";
}
/* line 194, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-sort-by-attributes-alt:before {
  content: "\e156";
}
/* line 195, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-unchecked:before {
  content: "\e157";
}
/* line 196, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-expand:before {
  content: "\e158";
}
/* line 197, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-collapse-down:before {
  content: "\e159";
}
/* line 198, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-collapse-up:before {
  content: "\e160";
}
/* line 199, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-log-in:before {
  content: "\e161";
}
/* line 200, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-flash:before {
  content: "\e162";
}
/* line 201, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-log-out:before {
  content: "\e163";
}
/* line 202, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-new-window:before {
  content: "\e164";
}
/* line 203, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-record:before {
  content: "\e165";
}
/* line 204, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-save:before {
  content: "\e166";
}
/* line 205, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-open:before {
  content: "\e167";
}
/* line 206, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-saved:before {
  content: "\e168";
}
/* line 207, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-import:before {
  content: "\e169";
}
/* line 208, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-export:before {
  content: "\e170";
}
/* line 209, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-send:before {
  content: "\e171";
}
/* line 210, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-floppy-disk:before {
  content: "\e172";
}
/* line 211, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-floppy-saved:before {
  content: "\e173";
}
/* line 212, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-floppy-remove:before {
  content: "\e174";
}
/* line 213, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-floppy-save:before {
  content: "\e175";
}
/* line 214, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-floppy-open:before {
  content: "\e176";
}
/* line 215, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-credit-card:before {
  content: "\e177";
}
/* line 216, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-transfer:before {
  content: "\e178";
}
/* line 217, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-cutlery:before {
  content: "\e179";
}
/* line 218, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-header:before {
  content: "\e180";
}
/* line 219, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-compressed:before {
  content: "\e181";
}
/* line 220, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-earphone:before {
  content: "\e182";
}
/* line 221, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-phone-alt:before {
  content: "\e183";
}
/* line 222, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-tower:before {
  content: "\e184";
}
/* line 223, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-stats:before {
  content: "\e185";
}
/* line 224, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-sd-video:before {
  content: "\e186";
}
/* line 225, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-hd-video:before {
  content: "\e187";
}
/* line 226, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-subtitles:before {
  content: "\e188";
}
/* line 227, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-sound-stereo:before {
  content: "\e189";
}
/* line 228, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-sound-dolby:before {
  content: "\e190";
}
/* line 229, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-sound-5-1:before {
  content: "\e191";
}
/* line 230, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-sound-6-1:before {
  content: "\e192";
}
/* line 231, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-sound-7-1:before {
  content: "\e193";
}
/* line 232, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-copyright-mark:before {
  content: "\e194";
}
/* line 233, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-registration-mark:before {
  content: "\e195";
}
/* line 234, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-cloud-download:before {
  content: "\e197";
}
/* line 235, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-cloud-upload:before {
  content: "\e198";
}
/* line 236, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-tree-conifer:before {
  content: "\e199";
}
/* line 237, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-tree-deciduous:before {
  content: "\e200";
}
/* line 238, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-cd:before {
  content: "\e201";
}
/* line 239, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-save-file:before {
  content: "\e202";
}
/* line 240, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-open-file:before {
  content: "\e203";
}
/* line 241, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-level-up:before {
  content: "\e204";
}
/* line 242, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-copy:before {
  content: "\e205";
}
/* line 243, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-paste:before {
  content: "\e206";
}
/* line 252, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-alert:before {
  content: "\e209";
}
/* line 253, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-equalizer:before {
  content: "\e210";
}
/* line 254, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-king:before {
  content: "\e211";
}
/* line 255, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-queen:before {
  content: "\e212";
}
/* line 256, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-pawn:before {
  content: "\e213";
}
/* line 257, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-bishop:before {
  content: "\e214";
}
/* line 258, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-knight:before {
  content: "\e215";
}
/* line 259, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-baby-formula:before {
  content: "\e216";
}
/* line 260, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-tent:before {
  content: "\26fa";
}
/* line 261, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-blackboard:before {
  content: "\e218";
}
/* line 262, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-bed:before {
  content: "\e219";
}
/* line 263, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-apple:before {
  content: "\f8ff";
}
/* line 264, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-erase:before {
  content: "\e221";
}
/* line 265, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-hourglass:before {
  content: "\231b";
}
/* line 266, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-lamp:before {
  content: "\e223";
}
/* line 267, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-duplicate:before {
  content: "\e224";
}
/* line 268, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-piggy-bank:before {
  content: "\e225";
}
/* line 269, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-scissors:before {
  content: "\e226";
}
/* line 270, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-bitcoin:before {
  content: "\e227";
}
/* line 271, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-btc:before {
  content: "\e227";
}
/* line 272, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-xbt:before {
  content: "\e227";
}
/* line 273, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-yen:before {
  content: "\00a5";
}
/* line 274, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-jpy:before {
  content: "\00a5";
}
/* line 275, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-ruble:before {
  content: "\20bd";
}
/* line 276, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-rub:before {
  content: "\20bd";
}
/* line 277, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-scale:before {
  content: "\e230";
}
/* line 278, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-ice-lolly:before {
  content: "\e231";
}
/* line 279, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-ice-lolly-tasted:before {
  content: "\e232";
}
/* line 280, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-education:before {
  content: "\e233";
}
/* line 281, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-option-horizontal:before {
  content: "\e234";
}
/* line 282, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-option-vertical:before {
  content: "\e235";
}
/* line 283, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-menu-hamburger:before {
  content: "\e236";
}
/* line 284, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-modal-window:before {
  content: "\e237";
}
/* line 285, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-oil:before {
  content: "\e238";
}
/* line 286, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-grain:before {
  content: "\e239";
}
/* line 287, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-sunglasses:before {
  content: "\e240";
}
/* line 288, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-text-size:before {
  content: "\e241";
}
/* line 289, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-text-color:before {
  content: "\e242";
}
/* line 290, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-text-background:before {
  content: "\e243";
}
/* line 291, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-object-align-top:before {
  content: "\e244";
}
/* line 292, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-object-align-bottom:before {
  content: "\e245";
}
/* line 293, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-object-align-horizontal:before {
  content: "\e246";
}
/* line 294, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-object-align-left:before {
  content: "\e247";
}
/* line 295, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-object-align-vertical:before {
  content: "\e248";
}
/* line 296, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-object-align-right:before {
  content: "\e249";
}
/* line 297, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-triangle-right:before {
  content: "\e250";
}
/* line 298, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-triangle-left:before {
  content: "\e251";
}
/* line 299, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-triangle-bottom:before {
  content: "\e252";
}
/* line 300, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-triangle-top:before {
  content: "\e253";
}
/* line 301, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-console:before {
  content: "\e254";
}
/* line 302, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-superscript:before {
  content: "\e255";
}
/* line 303, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-subscript:before {
  content: "\e256";
}
/* line 304, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-menu-left:before {
  content: "\e257";
}
/* line 305, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-menu-right:before {
  content: "\e258";
}
/* line 306, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-menu-down:before {
  content: "\e259";
}
/* line 307, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/glyphicons.less */
.glyphicon-menu-up:before {
  content: "\e260";
}
/* ui helper less rules */
/* line 32, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/modals.less */
.modal.pattern-relateditems-container .fade .modal-dialog {
  -webkit-transform: translate(0, -25%);
  -ms-transform: translate(0, -25%);
  -o-transform: translate(0, -25%);
  transform: translate(0, -25%);
  -webkit-transition: -webkit-transform 0.3s ease-out;
  -moz-transition: -moz-transform 0.3s ease-out;
  -o-transition: -o-transform 0.3s ease-out;
  transition: transform 0.3s ease-out;
}
/* line 73, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/modals.less */
.modal-backdrop.pattern-relateditems-container .fade {
  filter: alpha(opacity=0);
  opacity: 0;
}
/* line 110, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/modals.less */
.modal-footer .pattern-relateditems-container .btn + .pattern-relateditems-container .btn,
.modal-footer .pattern-pickadate-wrapper .btn + .pattern-pickadate-wrapper .btn,
.modal-footer .pattern-pickadate-wrapper .pattern-relateditems-container .btn + .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.modal-footer .pattern-relateditems-container .pattern-pickadate-wrapper .btn + .pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  margin-bottom: 0;
  margin-left: 5px;
}
/* line 115, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/modals.less */
.modal-footer .btn-group .pattern-relateditems-container .btn + .pattern-relateditems-container .btn,
.modal-footer .pattern-relateditems-container .btn-group .btn + .btn,
.modal-footer .btn-group .pattern-pickadate-wrapper .btn + .pattern-pickadate-wrapper .btn,
.modal-footer .btn-group .pattern-pickadate-wrapper .pattern-relateditems-container .btn + .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.modal-footer .btn-group .pattern-relateditems-container .pattern-pickadate-wrapper .btn + .pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  margin-left: -1px;
}
/* buttons */
/* line 13, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-btn {
  display: inline-block;
  margin-bottom: 0;
  font-weight: normal;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  touch-action: manipulation;
  cursor: pointer;
  background-image: none;
  border: 1px solid transparent;
  padding: 6px 12px;
  font-size: 14px;
  line-height: 1.42857143;
  border-radius: 4px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
/* line 34, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/buttons.less */
.plone-btn:hover,
.plone-btn:focus,
.plone-btn.focus {
  color: #333333;
  text-decoration: none;
}
/* line 41, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/buttons.less */
.plone-btn:active,
.plone-btn.active {
  background-image: none;
  outline: 0;
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}
/* line 48, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/buttons.less */
.plone-btn.disabled,
.plone-btn[disabled],
fieldset[disabled] .plone-btn {
  cursor: not-allowed;
  filter: alpha(opacity=65);
  opacity: 0.65;
  -webkit-box-shadow: none;
  box-shadow: none;
}
/* line 14, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-btn-lg {
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.3333333;
  border-radius: 6px;
}
/* line 15, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-btn-xs {
  padding: 1px 5px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
}
/* line 16, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-btn-sm {
  padding: 1px 5px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
}
/* line 18, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-btn-primary {
  color: #ffffff;
  background-color: #337ab7;
  border-color: #2e6da4;
}
/* line 11, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-primary:focus,
.plone-btn-primary.focus {
  color: #ffffff;
  background-color: #286090;
  border-color: #122b40;
}
/* line 17, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-primary:hover {
  color: #ffffff;
  background-color: #286090;
  border-color: #204d74;
}
/* line 22, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-primary:active,
.plone-btn-primary.active,
.open > .dropdown-toggle.plone-btn-primary,
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-primary,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-primary {
  color: #ffffff;
  background-color: #286090;
  background-image: none;
  border-color: #204d74;
}
/* line 30, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-primary:hover,
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-primary:focus,
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-primary.focus,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-primary:hover,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-primary:focus,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-primary.focus {
  color: #ffffff;
  background-color: #204d74;
  border-color: #122b40;
}
/* line 49, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-primary .badge {
  color: #337ab7;
  background-color: #ffffff;
}
/* line 19, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-btn-warning {
  color: #ffffff;
  background-color: #f0ad4e;
  border-color: #eea236;
}
/* line 11, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-warning:focus,
.plone-btn-warning.focus {
  color: #ffffff;
  background-color: #ec971f;
  border-color: #985f0d;
}
/* line 17, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-warning:hover {
  color: #ffffff;
  background-color: #ec971f;
  border-color: #d58512;
}
/* line 22, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-warning:active,
.plone-btn-warning.active,
.open > .dropdown-toggle.plone-btn-warning,
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-warning,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-warning {
  color: #ffffff;
  background-color: #ec971f;
  background-image: none;
  border-color: #d58512;
}
/* line 30, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-warning:hover,
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-warning:focus,
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-warning.focus,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-warning:hover,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-warning:focus,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-warning.focus {
  color: #ffffff;
  background-color: #d58512;
  border-color: #985f0d;
}
/* line 49, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-warning .badge {
  color: #f0ad4e;
  background-color: #ffffff;
}
/* line 20, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-btn-default {
  color: #333333;
  background-color: #ffffff;
  border-color: #cccccc;
}
/* line 11, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-default:focus,
.plone-btn-default.focus {
  color: #333333;
  background-color: #e6e6e6;
  border-color: #8c8c8c;
}
/* line 17, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-default:hover {
  color: #333333;
  background-color: #e6e6e6;
  border-color: #adadad;
}
/* line 22, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-default:active,
.plone-btn-default.active,
.open > .dropdown-toggle.plone-btn-default,
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-default,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-default {
  color: #333333;
  background-color: #e6e6e6;
  background-image: none;
  border-color: #adadad;
}
/* line 30, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-default:hover,
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-default:focus,
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-default.focus,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-default:hover,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-default:focus,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-default.focus {
  color: #333333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}
/* line 49, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-default .badge {
  color: #ffffff;
  background-color: #333333;
}
/* line 21, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-btn-success {
  color: #ffffff;
  background-color: #5cb85c;
  border-color: #4cae4c;
}
/* line 11, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-success:focus,
.plone-btn-success.focus {
  color: #ffffff;
  background-color: #449d44;
  border-color: #255625;
}
/* line 17, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-success:hover {
  color: #ffffff;
  background-color: #449d44;
  border-color: #398439;
}
/* line 22, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-success:active,
.plone-btn-success.active,
.open > .dropdown-toggle.plone-btn-success,
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-success,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-success {
  color: #ffffff;
  background-color: #449d44;
  background-image: none;
  border-color: #398439;
}
/* line 30, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-success:hover,
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-success:focus,
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-success.focus,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-success:hover,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-success:focus,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-success.focus {
  color: #ffffff;
  background-color: #398439;
  border-color: #255625;
}
/* line 49, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-success .badge {
  color: #5cb85c;
  background-color: #ffffff;
}
/* line 22, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-btn-info {
  color: #ffffff;
  background-color: #5bc0de;
  border-color: #46b8da;
}
/* line 11, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-info:focus,
.plone-btn-info.focus {
  color: #ffffff;
  background-color: #31b0d5;
  border-color: #1b6d85;
}
/* line 17, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-info:hover {
  color: #ffffff;
  background-color: #31b0d5;
  border-color: #269abc;
}
/* line 22, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-info:active,
.plone-btn-info.active,
.open > .dropdown-toggle.plone-btn-info,
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-info,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-info {
  color: #ffffff;
  background-color: #31b0d5;
  background-image: none;
  border-color: #269abc;
}
/* line 30, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-info:hover,
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-info:focus,
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-info.focus,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-info:hover,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-info:focus,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-info.focus {
  color: #ffffff;
  background-color: #269abc;
  border-color: #1b6d85;
}
/* line 49, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-info .badge {
  color: #5bc0de;
  background-color: #ffffff;
}
/* line 23, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-btn-danger {
  color: #ffffff;
  background-color: #d9534f;
  border-color: #d43f3a;
}
/* line 11, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-danger:focus,
.plone-btn-danger.focus {
  color: #ffffff;
  background-color: #c9302c;
  border-color: #761c19;
}
/* line 17, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-danger:hover {
  color: #ffffff;
  background-color: #c9302c;
  border-color: #ac2925;
}
/* line 22, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-danger:active,
.plone-btn-danger.active,
.open > .dropdown-toggle.plone-btn-danger,
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-danger,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-danger {
  color: #ffffff;
  background-color: #c9302c;
  background-image: none;
  border-color: #ac2925;
}
/* line 30, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-danger:hover,
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-danger:focus,
.open > .pattern-relateditems-container .dropdown-toggle.plone-btn-danger.focus,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-danger:hover,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-danger:focus,
.pattern-relateditems-container .open > .dropdown-toggle.plone-btn-danger.focus {
  color: #ffffff;
  background-color: #ac2925;
  border-color: #761c19;
}
/* line 49, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.plone-btn-danger .badge {
  color: #d9534f;
  background-color: #ffffff;
}
/* line 24, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-btn-link {
  font-weight: 400;
  color: #337ab7;
  border-radius: 0;
}
/* line 101, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/buttons.less */
.plone-btn-link,
.plone-btn-link:active,
.plone-btn-link.active,
.plone-btn-link[disabled],
fieldset[disabled] .plone-btn-link {
  background-color: transparent;
  -webkit-box-shadow: none;
  box-shadow: none;
}
/* line 109, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/buttons.less */
.plone-btn-link,
.plone-btn-link:hover,
.plone-btn-link:focus,
.plone-btn-link:active {
  border-color: transparent;
}
/* line 115, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/buttons.less */
.plone-btn-link:hover,
.plone-btn-link:focus {
  color: #23527c;
  text-decoration: underline;
  background-color: transparent;
}
/* line 27, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-btn-group .plone-btn + .plone-btn,
.plone-btn-group .plone-btn + .plone-btn-group,
.plone-btn-group .plone-btn-group + .plone-btn,
.plone-btn-group .plone-btn-group + .plone-btn-group {
  margin-left: -1px;
}
/* line 35, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-btn-block {
  display: block;
  width: 100%;
}
/* line 37, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-close {
  float: right;
  font-size: 21px;
  font-weight: bold;
  line-height: 1;
  color: #000000;
  text-shadow: 0 1px 0 #ffffff;
  filter: alpha(opacity=20);
  opacity: 0.2;
}
/* line 17, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/close.less */
.plone-close:hover,
.plone-close:focus {
  color: #000000;
  text-decoration: none;
  cursor: pointer;
  filter: alpha(opacity=50);
  opacity: 0.5;
}
/* line 29, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/close.less */
button.plone-close {
  padding: 0;
  cursor: pointer;
  background: transparent;
  border: 0;
  -webkit-appearance: none;
  appearance: none;
}
/* modals */
/* line 41, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-modal {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1050;
  display: none;
  overflow: hidden;
  -webkit-overflow-scrolling: touch;
  outline: 0;
}
/* line 32, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/modals.less */
.plone-modal.fade .modal-dialog,
.plone-modal.pattern-relateditems-container .fade .modal-dialog {
  -webkit-transform: translate(0, -25%);
  -ms-transform: translate(0, -25%);
  -o-transform: translate(0, -25%);
  transform: translate(0, -25%);
  -webkit-transition: -webkit-transform 0.3s ease-out;
  -moz-transition: -moz-transform 0.3s ease-out;
  -o-transition: -o-transform 0.3s ease-out;
  transition: transform 0.3s ease-out;
}
/* line 36, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/modals.less */
.plone-modal.in .modal-dialog {
  -webkit-transform: translate(0, 0);
  -ms-transform: translate(0, 0);
  -o-transform: translate(0, 0);
  transform: translate(0, 0);
}
/* line 42, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-modal-header {
  padding: 15px;
  border-bottom: 1px solid #e5e5e5;
}
/* line 43, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-modal-title {
  margin: 0;
  line-height: 1.42857143;
}
/* line 44, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-modal-body {
  position: relative;
  padding: 15px;
}
/* line 45, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-modal-footer {
  padding: 15px;
  text-align: right;
  border-top: 1px solid #e5e5e5;
}
/* line 110, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/modals.less */
.plone-modal-footer .btn + .btn,
.plone-modal-footer .pattern-relateditems-container .btn + .pattern-relateditems-container .btn,
.plone-modal-footer .pattern-pickadate-wrapper .btn + .pattern-pickadate-wrapper .btn,
.plone-modal-footer .pattern-pickadate-wrapper .pattern-relateditems-container .btn + .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.plone-modal-footer .pattern-relateditems-container .pattern-pickadate-wrapper .btn + .pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  margin-bottom: 0;
  margin-left: 5px;
}
/* line 115, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/modals.less */
.plone-modal-footer .btn-group .btn + .btn,
.plone-modal-footer .btn-group .pattern-relateditems-container .btn + .pattern-relateditems-container .btn,
.plone-modal-footer .pattern-relateditems-container .btn-group .btn + .btn,
.plone-modal-footer .btn-group .pattern-pickadate-wrapper .btn + .pattern-pickadate-wrapper .btn,
.plone-modal-footer .btn-group .pattern-pickadate-wrapper .pattern-relateditems-container .btn + .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.plone-modal-footer .btn-group .pattern-relateditems-container .pattern-pickadate-wrapper .btn + .pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  margin-left: -1px;
}
/* line 119, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/modals.less */
.plone-modal-footer .btn-block + .btn-block {
  margin-left: 0;
}
/* line 46, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-modal-backdrop {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1040;
  background-color: #000000;
}
/* line 73, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/modals.less */
.plone-modal-backdrop.fade,
.plone-modal-backdrop.pattern-relateditems-container .fade {
  filter: alpha(opacity=0);
  opacity: 0;
}
/* line 74, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/modals.less */
.plone-modal-backdrop.in {
  filter: alpha(opacity=50);
  opacity: 0.5;
}
/* progress */
/* line 50, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-progress {
  height: 20px;
  margin-bottom: 20px;
  overflow: hidden;
  background-color: #f5f5f5;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
  box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
}
/* line 51, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-progress-bar-striped {
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-size: 40px 40px;
}
/* line 52, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.plone-progress-bar {
  float: left;
  width: 0%;
  height: 100%;
  font-size: 12px;
  line-height: 20px;
  color: #ffffff;
  text-align: center;
  background-color: #337ab7;
  -webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  -webkit-transition: width 0.6s ease;
  -o-transition: width 0.6s ease;
  transition: width 0.6s ease;
}
/* rotate transforms */
/* line 55, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.rright {
  /* right-rotate by 90° */
  -ms-transform: rotate(90deg);
  /* IE 9 */
  -webkit-transform: rotate(90deg);
  /* iOS, Android */
  transform: rotate(90deg);
}
/* line 61, http://localhost:8080/ideabox/++resource++mockupless//base.less */
.rleft {
  /* left-rotate by 90° */
  -ms-transform: rotate(-90deg);
  /* IE 9 */
  -webkit-transform: rotate(-90deg);
  /* iOS, Android */
  transform: rotate(-90deg);
}
/* line 7, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/tooltip.less */
.mockup-tooltip.tooltip {
  position: absolute;
  z-index: 1070;
  display: block;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-style: normal;
  font-weight: 400;
  line-height: 1.42857143;
  line-break: auto;
  text-align: left;
  text-align: start;
  text-decoration: none;
  text-shadow: none;
  text-transform: none;
  letter-spacing: normal;
  word-break: normal;
  word-spacing: normal;
  word-wrap: normal;
  white-space: normal;
  font-size: 12px;
  filter: alpha(opacity=0);
  opacity: 0;
}
/* line 18, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/tooltip.less */
.mockup-tooltip.tooltip.in {
  filter: alpha(opacity=90);
  opacity: 0.9;
}
/* line 19, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/tooltip.less */
.mockup-tooltip.tooltip.top {
  padding: 5px 0;
  margin-top: -3px;
}
/* line 23, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/tooltip.less */
.mockup-tooltip.tooltip.right {
  padding: 0 5px;
  margin-left: 3px;
}
/* line 27, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/tooltip.less */
.mockup-tooltip.tooltip.bottom {
  padding: 5px 0;
  margin-top: 3px;
}
/* line 31, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/tooltip.less */
.mockup-tooltip.tooltip.left {
  padding: 0 5px;
  margin-left: -3px;
}
/* line 37, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/tooltip.less */
.mockup-tooltip.tooltip.top .tooltip-arrow,
.tooltip.top .mockup-tooltip .tooltip-arrow {
  bottom: 0;
  left: 50%;
  margin-left: -5px;
  border-width: 5px 5px 0;
  border-top-color: #000000;
}
/* line 44, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/tooltip.less */
.mockup-tooltip.tooltip.top-left .tooltip-arrow,
.tooltip.top-left .mockup-tooltip .tooltip-arrow {
  right: 5px;
  bottom: 0;
  margin-bottom: -5px;
  border-width: 5px 5px 0;
  border-top-color: #000000;
}
/* line 51, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/tooltip.less */
.mockup-tooltip.tooltip.top-right .tooltip-arrow,
.tooltip.top-right .mockup-tooltip .tooltip-arrow {
  bottom: 0;
  left: 5px;
  margin-bottom: -5px;
  border-width: 5px 5px 0;
  border-top-color: #000000;
}
/* line 58, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/tooltip.less */
.mockup-tooltip.tooltip.right .tooltip-arrow,
.tooltip.right .mockup-tooltip .tooltip-arrow {
  top: 50%;
  left: 0;
  margin-top: -5px;
  border-width: 5px 5px 5px 0;
  border-right-color: #000000;
}
/* line 65, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/tooltip.less */
.mockup-tooltip.tooltip.left .tooltip-arrow,
.tooltip.left .mockup-tooltip .tooltip-arrow {
  top: 50%;
  right: 0;
  margin-top: -5px;
  border-width: 5px 0 5px 5px;
  border-left-color: #000000;
}
/* line 72, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/tooltip.less */
.mockup-tooltip.tooltip.bottom .tooltip-arrow,
.tooltip.bottom .mockup-tooltip .tooltip-arrow {
  top: 0;
  left: 50%;
  margin-left: -5px;
  border-width: 0 5px 5px;
  border-bottom-color: #000000;
}
/* line 79, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/tooltip.less */
.mockup-tooltip.tooltip.bottom-left .tooltip-arrow,
.tooltip.bottom-left .mockup-tooltip .tooltip-arrow {
  top: 0;
  right: 5px;
  margin-top: -5px;
  border-width: 0 5px 5px;
  border-bottom-color: #000000;
}
/* line 86, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/tooltip.less */
.mockup-tooltip.tooltip.bottom-right .tooltip-arrow,
.tooltip.bottom-right .mockup-tooltip .tooltip-arrow {
  top: 0;
  left: 5px;
  margin-top: -5px;
  border-width: 0 5px 5px;
  border-bottom-color: #000000;
}
/* line 96, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/tooltip.less */
.mockup-tooltip .tooltip-inner {
  max-width: 200px;
  padding: 3px 8px;
  color: #ffffff;
  text-align: center;
  background-color: #000000;
  border-radius: 4px;
}
/* line 106, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/tooltip.less */
.mockup-tooltip .tooltip-arrow {
  position: absolute;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid;
}
/* loading icon animation */
/* line 6, http://localhost:8080/ideabox/++resource++mockupless//ui.less */
.plone-loader {
  display: none;
  position: fixed;
  top: 50%;
  left: calc(50% - 2.5em);
}
/* line 12, http://localhost:8080/ideabox/++resource++mockupless//ui.less */
.plone-loader div {
  margin: -6em auto;
  font-size: 5px;
  text-indent: -9999em;
  border-top: 1.1em solid rgba(39, 33, 33, 0.2);
  border-right: 1.1em solid rgba(218, 211, 211, 0.2);
  border-bottom: 1.1em solid rgba(218, 211, 211, 0.2);
  border-left: 1.1em solid rgba(218, 211, 211, 0.2);
  -webkit-transform: translateZ(0);
  -ms-transform: translateZ(0);
  transform: translateZ(0);
  -webkit-animation: load8 1.1s infinite linear;
  animation: load8 1.1s infinite linear;
}
/* line 26, http://localhost:8080/ideabox/++resource++mockupless//ui.less */
.plone-loader div,
.plone-loader div:after {
  border-radius: 50%;
  width: 10em;
  height: 10em;
}
@-webkit-keyframes load8 {
  /* line 33, http://localhost:8080/ideabox/++resource++mockupless//ui.less */
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  /* line 37, http://localhost:8080/ideabox/++resource++mockupless//ui.less */
  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}
@keyframes load8 {
  /* line 43, http://localhost:8080/ideabox/++resource++mockupless//ui.less */
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  /* line 47, http://localhost:8080/ideabox/++resource++mockupless//ui.less */
  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}
/* line 14, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/clearfix.less */
.modal-header:before,
.modal-header:after,
.modal-footer:before,
.modal-footer:after,
.plone-modal-header:before,
.plone-modal-header:after,
.plone-modal-footer:before,
.plone-modal-footer:after,
.btn-toolbar:before,
.btn-toolbar:after,
.btn-group-vertical > .btn-group:before,
.btn-group-vertical > .btn-group:after,
.btn-group-vertical > .pattern-relateditems-container .btn-group:before,
.btn-group-vertical > .pattern-relateditems-container .btn-group:after {
  display: table;
  content: " ";
}
/* line 19, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/clearfix.less */
.modal-header:after,
.modal-footer:after,
.plone-modal-header:after,
.plone-modal-footer:after,
.btn-toolbar:after,
.btn-group-vertical > .btn-group:after,
.btn-group-vertical > .pattern-relateditems-container .btn-group:after {
  clear: both;
}
/* line 11, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/buttons.less */
.pattern-relateditems-container .btn,
.pattern-pickadate-wrapper .btn,
.pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  display: inline-block;
  margin-bottom: 0;
  font-weight: normal;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  touch-action: manipulation;
  cursor: pointer;
  background-image: none;
  border: 1px solid transparent;
  padding: 6px 12px;
  font-size: 14px;
  line-height: 1.42857143;
  border-radius: 4px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
/* line 28, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/buttons.less */
.pattern-relateditems-container .btn:focus,
.pattern-relateditems-container .btn:active:focus,
.pattern-relateditems-container .btn.active:focus,
.pattern-relateditems-container .btn.focus,
.pattern-relateditems-container .btn:active.focus,
.pattern-relateditems-container .btn.active.focus,
.pattern-pickadate-wrapper .btn:focus,
.pattern-pickadate-wrapper .btn:active:focus,
.pattern-pickadate-wrapper .btn.active:focus,
.pattern-pickadate-wrapper .btn.focus,
.pattern-pickadate-wrapper .btn:active.focus,
.pattern-pickadate-wrapper .btn.active.focus,
.pattern-pickadate-wrapper .pattern-relateditems-container .btn:focus,
.pattern-pickadate-wrapper .pattern-relateditems-container .btn:active:focus,
.pattern-pickadate-wrapper .pattern-relateditems-container .btn.active:focus,
.pattern-pickadate-wrapper .pattern-relateditems-container .btn.focus,
.pattern-pickadate-wrapper .pattern-relateditems-container .btn:active.focus,
.pattern-pickadate-wrapper .pattern-relateditems-container .btn.active.focus,
.pattern-relateditems-container .pattern-pickadate-wrapper .btn:focus,
.pattern-relateditems-container .pattern-pickadate-wrapper .btn:active:focus,
.pattern-relateditems-container .pattern-pickadate-wrapper .btn.active:focus,
.pattern-relateditems-container .pattern-pickadate-wrapper .btn.focus,
.pattern-relateditems-container .pattern-pickadate-wrapper .btn:active.focus,
.pattern-relateditems-container .pattern-pickadate-wrapper .btn.active.focus {
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
/* line 34, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/buttons.less */
.pattern-relateditems-container .btn:hover,
.pattern-relateditems-container .btn:focus,
.pattern-relateditems-container .btn.focus,
.pattern-pickadate-wrapper .btn:hover,
.pattern-pickadate-wrapper .btn:focus,
.pattern-pickadate-wrapper .btn.focus,
.pattern-pickadate-wrapper .pattern-relateditems-container .btn:hover,
.pattern-pickadate-wrapper .pattern-relateditems-container .btn:focus,
.pattern-pickadate-wrapper .pattern-relateditems-container .btn.focus,
.pattern-relateditems-container .pattern-pickadate-wrapper .btn:hover,
.pattern-relateditems-container .pattern-pickadate-wrapper .btn:focus,
.pattern-relateditems-container .pattern-pickadate-wrapper .btn.focus {
  color: #333333;
  text-decoration: none;
}
/* line 41, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/buttons.less */
.pattern-relateditems-container .btn:active,
.pattern-relateditems-container .btn.active,
.pattern-pickadate-wrapper .btn:active,
.pattern-pickadate-wrapper .btn.active,
.pattern-pickadate-wrapper .pattern-relateditems-container .btn:active,
.pattern-pickadate-wrapper .pattern-relateditems-container .btn.active,
.pattern-relateditems-container .pattern-pickadate-wrapper .btn:active,
.pattern-relateditems-container .pattern-pickadate-wrapper .btn.active {
  background-image: none;
  outline: 0;
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}
/* line 48, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/buttons.less */
.pattern-relateditems-container .btn.disabled,
.pattern-relateditems-container .btn[disabled],
fieldset[disabled] .pattern-relateditems-container .btn,
.pattern-pickadate-wrapper .btn.disabled,
.pattern-pickadate-wrapper .btn[disabled],
fieldset[disabled] .pattern-pickadate-wrapper .btn,
.pattern-pickadate-wrapper .pattern-relateditems-container .btn.disabled,
.pattern-pickadate-wrapper .pattern-relateditems-container .btn[disabled],
fieldset[disabled] .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.pattern-relateditems-container .pattern-pickadate-wrapper .btn.disabled,
.pattern-relateditems-container .pattern-pickadate-wrapper .btn[disabled],
fieldset[disabled] .pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  cursor: not-allowed;
  filter: alpha(opacity=65);
  opacity: 0.65;
  -webkit-box-shadow: none;
  box-shadow: none;
}
/* line 57, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/buttons.less */
a.pattern-relateditems-container .btn.disabled,
fieldset[disabled] a.pattern-relateditems-container .btn,
a.pattern-pickadate-wrapper .btn.disabled,
fieldset[disabled] a.pattern-pickadate-wrapper .btn,
a.pattern-pickadate-wrapper .pattern-relateditems-container .btn.disabled,
fieldset[disabled] a.pattern-pickadate-wrapper .pattern-relateditems-container .btn,
a.pattern-relateditems-container .pattern-pickadate-wrapper .btn.disabled,
fieldset[disabled] a.pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  pointer-events: none;
}
/* line 68, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/buttons.less */
.pattern-relateditems-container .btn-default {
  color: #333333;
  background-color: #ffffff;
  border-color: #cccccc;
}
/* line 11, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-relateditems-container .btn-default:focus,
.pattern-relateditems-container .btn-default.focus {
  color: #333333;
  background-color: #e6e6e6;
  border-color: #8c8c8c;
}
/* line 17, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-relateditems-container .btn-default:hover {
  color: #333333;
  background-color: #e6e6e6;
  border-color: #adadad;
}
/* line 22, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-relateditems-container .btn-default:active,
.pattern-relateditems-container .btn-default.active,
.open > .dropdown-toggle.pattern-relateditems-container .btn-default,
.open > .pattern-relateditems-container .dropdown-toggle.btn-default,
.pattern-relateditems-container .open > .dropdown-toggle.btn-default {
  color: #333333;
  background-color: #e6e6e6;
  background-image: none;
  border-color: #adadad;
}
/* line 30, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-relateditems-container .btn-default:active:hover,
.pattern-relateditems-container .btn-default.active:hover,
.open > .dropdown-toggle.pattern-relateditems-container .btn-default:hover,
.pattern-relateditems-container .btn-default:active:focus,
.pattern-relateditems-container .btn-default.active:focus,
.open > .dropdown-toggle.pattern-relateditems-container .btn-default:focus,
.pattern-relateditems-container .btn-default:active.focus,
.pattern-relateditems-container .btn-default.active.focus,
.open > .dropdown-toggle.pattern-relateditems-container .btn-default.focus,
.open > .pattern-relateditems-container .dropdown-toggle.btn-default:hover,
.open > .pattern-relateditems-container .dropdown-toggle.btn-default:focus,
.open > .pattern-relateditems-container .dropdown-toggle.btn-default.focus,
.pattern-relateditems-container .open > .dropdown-toggle.btn-default:hover,
.pattern-relateditems-container .open > .dropdown-toggle.btn-default:focus,
.pattern-relateditems-container .open > .dropdown-toggle.btn-default.focus {
  color: #333333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}
/* line 41, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-relateditems-container .btn-default.disabled:hover,
.pattern-relateditems-container .btn-default[disabled]:hover,
fieldset[disabled] .pattern-relateditems-container .btn-default:hover,
.pattern-relateditems-container .btn-default.disabled:focus,
.pattern-relateditems-container .btn-default[disabled]:focus,
fieldset[disabled] .pattern-relateditems-container .btn-default:focus,
.pattern-relateditems-container .btn-default.disabled.focus,
.pattern-relateditems-container .btn-default[disabled].focus,
fieldset[disabled] .pattern-relateditems-container .btn-default.focus {
  background-color: #ffffff;
  border-color: #cccccc;
}
/* line 49, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-relateditems-container .btn-default .badge {
  color: #ffffff;
  background-color: #333333;
}
/* line 71, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/buttons.less */
.pattern-relateditems-container .btn-primary {
  color: #ffffff;
  background-color: #337ab7;
  border-color: #2e6da4;
}
/* line 11, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-relateditems-container .btn-primary:focus,
.pattern-relateditems-container .btn-primary.focus {
  color: #ffffff;
  background-color: #286090;
  border-color: #122b40;
}
/* line 17, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-relateditems-container .btn-primary:hover {
  color: #ffffff;
  background-color: #286090;
  border-color: #204d74;
}
/* line 22, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-relateditems-container .btn-primary:active,
.pattern-relateditems-container .btn-primary.active,
.open > .dropdown-toggle.pattern-relateditems-container .btn-primary,
.open > .pattern-relateditems-container .dropdown-toggle.btn-primary,
.pattern-relateditems-container .open > .dropdown-toggle.btn-primary {
  color: #ffffff;
  background-color: #286090;
  background-image: none;
  border-color: #204d74;
}
/* line 30, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-relateditems-container .btn-primary:active:hover,
.pattern-relateditems-container .btn-primary.active:hover,
.open > .dropdown-toggle.pattern-relateditems-container .btn-primary:hover,
.pattern-relateditems-container .btn-primary:active:focus,
.pattern-relateditems-container .btn-primary.active:focus,
.open > .dropdown-toggle.pattern-relateditems-container .btn-primary:focus,
.pattern-relateditems-container .btn-primary:active.focus,
.pattern-relateditems-container .btn-primary.active.focus,
.open > .dropdown-toggle.pattern-relateditems-container .btn-primary.focus,
.open > .pattern-relateditems-container .dropdown-toggle.btn-primary:hover,
.open > .pattern-relateditems-container .dropdown-toggle.btn-primary:focus,
.open > .pattern-relateditems-container .dropdown-toggle.btn-primary.focus,
.pattern-relateditems-container .open > .dropdown-toggle.btn-primary:hover,
.pattern-relateditems-container .open > .dropdown-toggle.btn-primary:focus,
.pattern-relateditems-container .open > .dropdown-toggle.btn-primary.focus {
  color: #ffffff;
  background-color: #204d74;
  border-color: #122b40;
}
/* line 41, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-relateditems-container .btn-primary.disabled:hover,
.pattern-relateditems-container .btn-primary[disabled]:hover,
fieldset[disabled] .pattern-relateditems-container .btn-primary:hover,
.pattern-relateditems-container .btn-primary.disabled:focus,
.pattern-relateditems-container .btn-primary[disabled]:focus,
fieldset[disabled] .pattern-relateditems-container .btn-primary:focus,
.pattern-relateditems-container .btn-primary.disabled.focus,
.pattern-relateditems-container .btn-primary[disabled].focus,
fieldset[disabled] .pattern-relateditems-container .btn-primary.focus {
  background-color: #337ab7;
  border-color: #2e6da4;
}
/* line 49, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-relateditems-container .btn-primary .badge {
  color: #337ab7;
  background-color: #ffffff;
}
/* line 22, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.open > .pattern-relateditems-container .dropdown-toggle.btn-success,
.pattern-relateditems-container .open > .dropdown-toggle.btn-success {
  color: #ffffff;
  background-color: #449d44;
  background-image: none;
  border-color: #398439;
}
/* line 30, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.open > .pattern-relateditems-container .dropdown-toggle.btn-success:hover,
.open > .pattern-relateditems-container .dropdown-toggle.btn-success:focus,
.open > .pattern-relateditems-container .dropdown-toggle.btn-success.focus,
.pattern-relateditems-container .open > .dropdown-toggle.btn-success:hover,
.pattern-relateditems-container .open > .dropdown-toggle.btn-success:focus,
.pattern-relateditems-container .open > .dropdown-toggle.btn-success.focus {
  color: #ffffff;
  background-color: #398439;
  border-color: #255625;
}
/* line 79, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/buttons.less */
.pattern-pickadate-wrapper .btn-info {
  color: #ffffff;
  background-color: #5bc0de;
  border-color: #46b8da;
}
/* line 11, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-pickadate-wrapper .btn-info:focus,
.pattern-pickadate-wrapper .btn-info.focus {
  color: #ffffff;
  background-color: #31b0d5;
  border-color: #1b6d85;
}
/* line 17, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-pickadate-wrapper .btn-info:hover {
  color: #ffffff;
  background-color: #31b0d5;
  border-color: #269abc;
}
/* line 22, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.open > .pattern-relateditems-container .dropdown-toggle.btn-info,
.pattern-relateditems-container .open > .dropdown-toggle.btn-info,
.pattern-pickadate-wrapper .btn-info:active,
.pattern-pickadate-wrapper .btn-info.active,
.open > .dropdown-toggle.pattern-pickadate-wrapper .btn-info {
  color: #ffffff;
  background-color: #31b0d5;
  background-image: none;
  border-color: #269abc;
}
/* line 30, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.open > .pattern-relateditems-container .dropdown-toggle.btn-info:hover,
.open > .pattern-relateditems-container .dropdown-toggle.btn-info:focus,
.open > .pattern-relateditems-container .dropdown-toggle.btn-info.focus,
.pattern-relateditems-container .open > .dropdown-toggle.btn-info:hover,
.pattern-relateditems-container .open > .dropdown-toggle.btn-info:focus,
.pattern-relateditems-container .open > .dropdown-toggle.btn-info.focus,
.pattern-pickadate-wrapper .btn-info:active:hover,
.pattern-pickadate-wrapper .btn-info.active:hover,
.open > .dropdown-toggle.pattern-pickadate-wrapper .btn-info:hover,
.pattern-pickadate-wrapper .btn-info:active:focus,
.pattern-pickadate-wrapper .btn-info.active:focus,
.open > .dropdown-toggle.pattern-pickadate-wrapper .btn-info:focus,
.pattern-pickadate-wrapper .btn-info:active.focus,
.pattern-pickadate-wrapper .btn-info.active.focus,
.open > .dropdown-toggle.pattern-pickadate-wrapper .btn-info.focus {
  color: #ffffff;
  background-color: #269abc;
  border-color: #1b6d85;
}
/* line 41, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-pickadate-wrapper .btn-info.disabled:hover,
.pattern-pickadate-wrapper .btn-info[disabled]:hover,
fieldset[disabled] .pattern-pickadate-wrapper .btn-info:hover,
.pattern-pickadate-wrapper .btn-info.disabled:focus,
.pattern-pickadate-wrapper .btn-info[disabled]:focus,
fieldset[disabled] .pattern-pickadate-wrapper .btn-info:focus,
.pattern-pickadate-wrapper .btn-info.disabled.focus,
.pattern-pickadate-wrapper .btn-info[disabled].focus,
fieldset[disabled] .pattern-pickadate-wrapper .btn-info.focus {
  background-color: #5bc0de;
  border-color: #46b8da;
}
/* line 49, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-pickadate-wrapper .btn-info .badge {
  color: #5bc0de;
  background-color: #ffffff;
}
/* line 22, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.open > .pattern-relateditems-container .dropdown-toggle.btn-warning,
.pattern-relateditems-container .open > .dropdown-toggle.btn-warning {
  color: #ffffff;
  background-color: #ec971f;
  background-image: none;
  border-color: #d58512;
}
/* line 30, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.open > .pattern-relateditems-container .dropdown-toggle.btn-warning:hover,
.open > .pattern-relateditems-container .dropdown-toggle.btn-warning:focus,
.open > .pattern-relateditems-container .dropdown-toggle.btn-warning.focus,
.pattern-relateditems-container .open > .dropdown-toggle.btn-warning:hover,
.pattern-relateditems-container .open > .dropdown-toggle.btn-warning:focus,
.pattern-relateditems-container .open > .dropdown-toggle.btn-warning.focus {
  color: #ffffff;
  background-color: #d58512;
  border-color: #985f0d;
}
/* line 87, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/buttons.less */
.pattern-pickadate-wrapper .btn-danger {
  color: #ffffff;
  background-color: #d9534f;
  border-color: #d43f3a;
}
/* line 11, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-pickadate-wrapper .btn-danger:focus,
.pattern-pickadate-wrapper .btn-danger.focus {
  color: #ffffff;
  background-color: #c9302c;
  border-color: #761c19;
}
/* line 17, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-pickadate-wrapper .btn-danger:hover {
  color: #ffffff;
  background-color: #c9302c;
  border-color: #ac2925;
}
/* line 22, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.open > .pattern-relateditems-container .dropdown-toggle.btn-danger,
.pattern-relateditems-container .open > .dropdown-toggle.btn-danger,
.pattern-pickadate-wrapper .btn-danger:active,
.pattern-pickadate-wrapper .btn-danger.active,
.open > .dropdown-toggle.pattern-pickadate-wrapper .btn-danger {
  color: #ffffff;
  background-color: #c9302c;
  background-image: none;
  border-color: #ac2925;
}
/* line 30, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.open > .pattern-relateditems-container .dropdown-toggle.btn-danger:hover,
.open > .pattern-relateditems-container .dropdown-toggle.btn-danger:focus,
.open > .pattern-relateditems-container .dropdown-toggle.btn-danger.focus,
.pattern-relateditems-container .open > .dropdown-toggle.btn-danger:hover,
.pattern-relateditems-container .open > .dropdown-toggle.btn-danger:focus,
.pattern-relateditems-container .open > .dropdown-toggle.btn-danger.focus,
.pattern-pickadate-wrapper .btn-danger:active:hover,
.pattern-pickadate-wrapper .btn-danger.active:hover,
.open > .dropdown-toggle.pattern-pickadate-wrapper .btn-danger:hover,
.pattern-pickadate-wrapper .btn-danger:active:focus,
.pattern-pickadate-wrapper .btn-danger.active:focus,
.open > .dropdown-toggle.pattern-pickadate-wrapper .btn-danger:focus,
.pattern-pickadate-wrapper .btn-danger:active.focus,
.pattern-pickadate-wrapper .btn-danger.active.focus,
.open > .dropdown-toggle.pattern-pickadate-wrapper .btn-danger.focus {
  color: #ffffff;
  background-color: #ac2925;
  border-color: #761c19;
}
/* line 41, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-pickadate-wrapper .btn-danger.disabled:hover,
.pattern-pickadate-wrapper .btn-danger[disabled]:hover,
fieldset[disabled] .pattern-pickadate-wrapper .btn-danger:hover,
.pattern-pickadate-wrapper .btn-danger.disabled:focus,
.pattern-pickadate-wrapper .btn-danger[disabled]:focus,
fieldset[disabled] .pattern-pickadate-wrapper .btn-danger:focus,
.pattern-pickadate-wrapper .btn-danger.disabled.focus,
.pattern-pickadate-wrapper .btn-danger[disabled].focus,
fieldset[disabled] .pattern-pickadate-wrapper .btn-danger.focus {
  background-color: #d9534f;
  border-color: #d43f3a;
}
/* line 49, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/mixins/buttons.less */
.pattern-pickadate-wrapper .btn-danger .badge {
  color: #d9534f;
  background-color: #ffffff;
}
/* line 135, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/buttons.less */
.btn-group-lg > .btn,
.btn-group-lg > .pattern-relateditems-container .btn,
.btn-group-lg > .pattern-pickadate-wrapper .btn,
.btn-group-lg > .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.btn-group-lg > .pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.3333333;
  border-radius: 6px;
}
/* line 139, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/buttons.less */
.btn-group-sm > .btn,
.pattern-relateditems-container .toolbar .btn,
.btn-group-sm > .pattern-relateditems-container .btn,
.pattern-relateditems-container .toolbar .pattern-relateditems-container .btn,
.btn-group-sm > .pattern-pickadate-wrapper .btn,
.pattern-relateditems-container .toolbar .pattern-pickadate-wrapper .btn,
.btn-group-sm > .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.pattern-relateditems-container .toolbar .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.btn-group-sm > .pattern-relateditems-container .pattern-pickadate-wrapper .btn,
.pattern-relateditems-container .toolbar .pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
}
/* line 143, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/buttons.less */
.btn-group-xs > .btn,
.btn-group-xs > .pattern-relateditems-container .btn,
.btn-group-xs > .pattern-pickadate-wrapper .btn,
.btn-group-xs > .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.btn-group-xs > .pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  padding: 1px 5px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
}
/* line 8, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.pattern-relateditems-container .btn-group {
  position: relative;
  display: inline-block;
  vertical-align: middle;
}
/* line 13, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group > .pattern-relateditems-container .btn,
.btn-group-vertical > .pattern-relateditems-container .btn,
.pattern-relateditems-container .btn-group > .btn,
.btn-group > .pattern-pickadate-wrapper .btn,
.btn-group-vertical > .pattern-pickadate-wrapper .btn,
.btn-group > .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.btn-group-vertical > .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.btn-group > .pattern-relateditems-container .pattern-pickadate-wrapper .btn,
.btn-group-vertical > .pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  position: relative;
  float: left;
}
/* line 17, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group > .pattern-relateditems-container .btn:hover,
.btn-group-vertical > .pattern-relateditems-container .btn:hover,
.btn-group > .pattern-relateditems-container .btn:focus,
.btn-group-vertical > .pattern-relateditems-container .btn:focus,
.btn-group > .pattern-relateditems-container .btn:active,
.btn-group-vertical > .pattern-relateditems-container .btn:active,
.btn-group > .pattern-relateditems-container .btn.active,
.btn-group-vertical > .pattern-relateditems-container .btn.active,
.pattern-relateditems-container .btn-group > .btn:hover,
.pattern-relateditems-container .btn-group > .btn:focus,
.pattern-relateditems-container .btn-group > .btn:active,
.pattern-relateditems-container .btn-group > .btn.active,
.btn-group > .pattern-pickadate-wrapper .btn:hover,
.btn-group-vertical > .pattern-pickadate-wrapper .btn:hover,
.btn-group > .pattern-pickadate-wrapper .btn:focus,
.btn-group-vertical > .pattern-pickadate-wrapper .btn:focus,
.btn-group > .pattern-pickadate-wrapper .btn:active,
.btn-group-vertical > .pattern-pickadate-wrapper .btn:active,
.btn-group > .pattern-pickadate-wrapper .btn.active,
.btn-group-vertical > .pattern-pickadate-wrapper .btn.active,
.btn-group > .pattern-pickadate-wrapper .pattern-relateditems-container .btn:hover,
.btn-group-vertical > .pattern-pickadate-wrapper .pattern-relateditems-container .btn:hover,
.btn-group > .pattern-pickadate-wrapper .pattern-relateditems-container .btn:focus,
.btn-group-vertical > .pattern-pickadate-wrapper .pattern-relateditems-container .btn:focus,
.btn-group > .pattern-pickadate-wrapper .pattern-relateditems-container .btn:active,
.btn-group-vertical > .pattern-pickadate-wrapper .pattern-relateditems-container .btn:active,
.btn-group > .pattern-pickadate-wrapper .pattern-relateditems-container .btn.active,
.btn-group-vertical > .pattern-pickadate-wrapper .pattern-relateditems-container .btn.active,
.btn-group > .pattern-relateditems-container .pattern-pickadate-wrapper .btn:hover,
.btn-group-vertical > .pattern-relateditems-container .pattern-pickadate-wrapper .btn:hover,
.btn-group > .pattern-relateditems-container .pattern-pickadate-wrapper .btn:focus,
.btn-group-vertical > .pattern-relateditems-container .pattern-pickadate-wrapper .btn:focus,
.btn-group > .pattern-relateditems-container .pattern-pickadate-wrapper .btn:active,
.btn-group-vertical > .pattern-relateditems-container .pattern-pickadate-wrapper .btn:active,
.btn-group > .pattern-relateditems-container .pattern-pickadate-wrapper .btn.active,
.btn-group-vertical > .pattern-relateditems-container .pattern-pickadate-wrapper .btn.active {
  z-index: 2;
}
/* line 28, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group .pattern-relateditems-container .btn + .pattern-relateditems-container .btn,
.btn-group .pattern-relateditems-container .btn + .btn-group,
.btn-group .btn-group + .pattern-relateditems-container .btn,
.pattern-relateditems-container .btn-group .btn + .btn,
.pattern-relateditems-container .btn-group .btn + .pattern-relateditems-container .btn-group,
.pattern-relateditems-container .btn-group .pattern-relateditems-container .btn-group + .btn,
.pattern-relateditems-container .btn-group .pattern-relateditems-container .btn-group + .pattern-relateditems-container .btn-group,
.btn-group .pattern-pickadate-wrapper .btn + .pattern-pickadate-wrapper .btn,
.btn-group .pattern-pickadate-wrapper .btn + .btn-group,
.btn-group .btn-group + .pattern-pickadate-wrapper .btn,
.btn-group .pattern-pickadate-wrapper .pattern-relateditems-container .btn + .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.btn-group .pattern-pickadate-wrapper .pattern-relateditems-container .btn + .btn-group,
.btn-group .btn-group + .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.btn-group .pattern-relateditems-container .pattern-pickadate-wrapper .btn + .pattern-relateditems-container .pattern-pickadate-wrapper .btn,
.btn-group .pattern-relateditems-container .pattern-pickadate-wrapper .btn + .btn-group,
.btn-group .btn-group + .pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  margin-left: -1px;
}
/* line 41, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-toolbar .pattern-relateditems-container .btn,
.btn-toolbar .pattern-relateditems-container .btn-group,
.btn-toolbar .pattern-relateditems-container .input-group,
.btn-toolbar .pattern-pickadate-wrapper .btn,
.btn-toolbar .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.btn-toolbar .pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  float: left;
}
/* line 46, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-toolbar > .pattern-relateditems-container .btn,
.btn-toolbar > .pattern-relateditems-container .btn-group,
.btn-toolbar > .pattern-relateditems-container .input-group,
.btn-toolbar > .pattern-pickadate-wrapper .btn,
.btn-toolbar > .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.btn-toolbar > .pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  margin-left: 5px;
}
/* line 53, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group > .pattern-relateditems-container .btn:not(:first-child):not(:last-child):not(.dropdown-toggle),
.pattern-relateditems-container .btn-group > .btn:not(:first-child):not(:last-child):not(.dropdown-toggle),
.btn-group > .pattern-pickadate-wrapper .btn:not(:first-child):not(:last-child):not(.dropdown-toggle),
.btn-group > .pattern-pickadate-wrapper .pattern-relateditems-container .btn:not(:first-child):not(:last-child):not(.dropdown-toggle),
.btn-group > .pattern-relateditems-container .pattern-pickadate-wrapper .btn:not(:first-child):not(:last-child):not(.dropdown-toggle) {
  border-radius: 0;
}
/* line 58, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group > .pattern-relateditems-container .btn:first-child,
.pattern-relateditems-container .btn-group > .btn:first-child,
.btn-group > .pattern-pickadate-wrapper .btn:first-child,
.btn-group > .pattern-pickadate-wrapper .pattern-relateditems-container .btn:first-child,
.btn-group > .pattern-relateditems-container .pattern-pickadate-wrapper .btn:first-child {
  margin-left: 0;
}
/* line 60, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group > .pattern-relateditems-container .btn:first-child:not(:last-child):not(.dropdown-toggle),
.pattern-relateditems-container .btn-group > .btn:first-child:not(:last-child):not(.dropdown-toggle),
.btn-group > .pattern-pickadate-wrapper .btn:first-child:not(:last-child):not(.dropdown-toggle),
.btn-group > .pattern-pickadate-wrapper .pattern-relateditems-container .btn:first-child:not(:last-child):not(.dropdown-toggle),
.btn-group > .pattern-relateditems-container .pattern-pickadate-wrapper .btn:first-child:not(:last-child):not(.dropdown-toggle) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}
/* line 65, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group > .pattern-relateditems-container .btn:last-child:not(:first-child),
.pattern-relateditems-container .btn-group > .btn:last-child:not(:first-child),
.pattern-relateditems-container .btn-group > .dropdown-toggle:not(:first-child),
.btn-group > .pattern-relateditems-container .dropdown-toggle:not(:first-child),
.btn-group > .pattern-pickadate-wrapper .btn:last-child:not(:first-child),
.btn-group > .pattern-pickadate-wrapper .pattern-relateditems-container .btn:last-child:not(:first-child),
.btn-group > .pattern-relateditems-container .pattern-pickadate-wrapper .btn:last-child:not(:first-child) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
/* line 71, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.pattern-relateditems-container .btn-group > .pattern-relateditems-container .btn-group {
  float: left;
}
/* line 74, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group > .btn-group:not(:first-child):not(:last-child) > .pattern-relateditems-container .btn,
.pattern-relateditems-container .btn-group > .pattern-relateditems-container .btn-group:not(:first-child):not(:last-child) > .btn,
.btn-group > .btn-group:not(:first-child):not(:last-child) > .pattern-pickadate-wrapper .btn,
.btn-group > .btn-group:not(:first-child):not(:last-child) > .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.btn-group > .btn-group:not(:first-child):not(:last-child) > .pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  border-radius: 0;
}
/* line 78, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group > .btn-group:first-child:not(:last-child) > .pattern-relateditems-container .btn:last-child,
.pattern-relateditems-container .btn-group > .pattern-relateditems-container .btn-group:first-child:not(:last-child) > .btn:last-child,
.pattern-relateditems-container .btn-group > .pattern-relateditems-container .btn-group:first-child:not(:last-child) > .dropdown-toggle,
.btn-group > .btn-group:first-child:not(:last-child) > .pattern-relateditems-container .dropdown-toggle,
.btn-group > .btn-group:first-child:not(:last-child) > .pattern-pickadate-wrapper .btn:last-child,
.btn-group > .btn-group:first-child:not(:last-child) > .pattern-pickadate-wrapper .pattern-relateditems-container .btn:last-child,
.btn-group > .btn-group:first-child:not(:last-child) > .pattern-relateditems-container .pattern-pickadate-wrapper .btn:last-child {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}
/* line 83, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group > .btn-group:last-child:not(:first-child) > .pattern-relateditems-container .btn:first-child,
.pattern-relateditems-container .btn-group > .pattern-relateditems-container .btn-group:last-child:not(:first-child) > .btn:first-child,
.btn-group > .btn-group:last-child:not(:first-child) > .pattern-pickadate-wrapper .btn:first-child,
.btn-group > .btn-group:last-child:not(:first-child) > .pattern-pickadate-wrapper .pattern-relateditems-container .btn:first-child,
.btn-group > .btn-group:last-child:not(:first-child) > .pattern-relateditems-container .pattern-pickadate-wrapper .btn:first-child {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
/* line 88, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.pattern-relateditems-container .btn-group .dropdown-toggle:active,
.pattern-relateditems-container .btn-group.open .dropdown-toggle,
.btn-group .pattern-relateditems-container .dropdown-toggle:active,
.btn-group.open .pattern-relateditems-container .dropdown-toggle,
.btn-group.pattern-relateditems-container .open .dropdown-toggle {
  outline: 0;
}
/* line 107, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group > .pattern-relateditems-container .btn + .dropdown-toggle,
.pattern-relateditems-container .btn-group > .btn + .dropdown-toggle,
.btn-group > .btn + .pattern-relateditems-container .dropdown-toggle,
.btn-group > .pattern-pickadate-wrapper .btn + .dropdown-toggle,
.btn-group > .pattern-pickadate-wrapper .pattern-relateditems-container .btn + .dropdown-toggle,
.btn-group > .pattern-relateditems-container .pattern-pickadate-wrapper .btn + .dropdown-toggle {
  padding-right: 8px;
  padding-left: 8px;
}
/* line 111, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.pattern-relateditems-container .btn-group > .btn-lg + .dropdown-toggle,
.btn-group > .btn-lg + .pattern-relateditems-container .dropdown-toggle {
  padding-right: 12px;
  padding-left: 12px;
}
/* line 118, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.pattern-relateditems-container .btn-group.open .dropdown-toggle,
.btn-group.open .pattern-relateditems-container .dropdown-toggle,
.btn-group.pattern-relateditems-container .open .dropdown-toggle {
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}
/* line 122, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.pattern-relateditems-container .btn-group.open .dropdown-toggle.btn-link,
.btn-group.open .pattern-relateditems-container .dropdown-toggle.btn-link,
.btn-group.pattern-relateditems-container .open .dropdown-toggle.btn-link {
  -webkit-box-shadow: none;
  box-shadow: none;
}
/* line 129, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.pattern-relateditems-container .btn .caret,
.pattern-pickadate-wrapper .btn .caret,
.pattern-pickadate-wrapper .pattern-relateditems-container .btn .caret,
.pattern-relateditems-container .pattern-pickadate-wrapper .btn .caret {
  margin-left: 0;
}
/* line 147, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group-vertical > .pattern-relateditems-container .btn,
.btn-group-vertical > .btn-group > .pattern-relateditems-container .btn,
.btn-group-vertical > .pattern-relateditems-container .btn-group,
.btn-group-vertical > .pattern-relateditems-container .btn-group > .btn,
.btn-group-vertical > .pattern-pickadate-wrapper .btn,
.btn-group-vertical > .btn-group > .pattern-pickadate-wrapper .btn,
.btn-group-vertical > .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.btn-group-vertical > .btn-group > .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.btn-group-vertical > .pattern-relateditems-container .pattern-pickadate-wrapper .btn,
.btn-group-vertical > .btn-group > .pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  display: block;
  float: none;
  width: 100%;
  max-width: 100%;
}
/* line 159, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group-vertical > .btn-group > .pattern-relateditems-container .btn,
.btn-group-vertical > .pattern-relateditems-container .btn-group > .btn,
.btn-group-vertical > .btn-group > .pattern-pickadate-wrapper .btn,
.btn-group-vertical > .btn-group > .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.btn-group-vertical > .btn-group > .pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  float: none;
}
/* line 164, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group-vertical > .pattern-relateditems-container .btn + .pattern-relateditems-container .btn,
.btn-group-vertical > .pattern-relateditems-container .btn + .btn-group,
.btn-group-vertical > .btn-group + .pattern-relateditems-container .btn,
.btn-group-vertical > .btn + .pattern-relateditems-container .btn-group,
.btn-group-vertical > .pattern-relateditems-container .btn-group + .btn,
.btn-group-vertical > .pattern-relateditems-container .btn-group + .pattern-relateditems-container .btn-group,
.btn-group-vertical > .pattern-pickadate-wrapper .btn + .pattern-pickadate-wrapper .btn,
.btn-group-vertical > .pattern-pickadate-wrapper .btn + .btn-group,
.btn-group-vertical > .btn-group + .pattern-pickadate-wrapper .btn,
.btn-group-vertical > .pattern-pickadate-wrapper .pattern-relateditems-container .btn + .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.btn-group-vertical > .pattern-pickadate-wrapper .pattern-relateditems-container .btn + .btn-group,
.btn-group-vertical > .btn-group + .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.btn-group-vertical > .pattern-relateditems-container .pattern-pickadate-wrapper .btn + .pattern-relateditems-container .pattern-pickadate-wrapper .btn,
.btn-group-vertical > .pattern-relateditems-container .pattern-pickadate-wrapper .btn + .btn-group,
.btn-group-vertical > .btn-group + .pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  margin-top: -1px;
  margin-left: 0;
}
/* line 174, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group-vertical > .pattern-relateditems-container .btn:not(:first-child):not(:last-child),
.btn-group-vertical > .pattern-pickadate-wrapper .btn:not(:first-child):not(:last-child),
.btn-group-vertical > .pattern-pickadate-wrapper .pattern-relateditems-container .btn:not(:first-child):not(:last-child),
.btn-group-vertical > .pattern-relateditems-container .pattern-pickadate-wrapper .btn:not(:first-child):not(:last-child) {
  border-radius: 0;
}
/* line 177, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group-vertical > .pattern-relateditems-container .btn:first-child:not(:last-child),
.btn-group-vertical > .pattern-pickadate-wrapper .btn:first-child:not(:last-child),
.btn-group-vertical > .pattern-pickadate-wrapper .pattern-relateditems-container .btn:first-child:not(:last-child),
.btn-group-vertical > .pattern-relateditems-container .pattern-pickadate-wrapper .btn:first-child:not(:last-child) {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}
/* line 181, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group-vertical > .pattern-relateditems-container .btn:last-child:not(:first-child),
.btn-group-vertical > .pattern-pickadate-wrapper .btn:last-child:not(:first-child),
.btn-group-vertical > .pattern-pickadate-wrapper .pattern-relateditems-container .btn:last-child:not(:first-child),
.btn-group-vertical > .pattern-relateditems-container .pattern-pickadate-wrapper .btn:last-child:not(:first-child) {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  border-bottom-right-radius: 4px;
  border-bottom-left-radius: 4px;
}
/* line 186, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .pattern-relateditems-container .btn,
.btn-group-vertical > .pattern-relateditems-container .btn-group:not(:first-child):not(:last-child) > .btn,
.btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .pattern-pickadate-wrapper .btn,
.btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  border-radius: 0;
}
/* line 190, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group-vertical > .btn-group:first-child:not(:last-child) > .pattern-relateditems-container .btn:last-child,
.btn-group-vertical > .pattern-relateditems-container .btn-group:first-child:not(:last-child) > .btn:last-child,
.btn-group-vertical > .pattern-relateditems-container .btn-group:first-child:not(:last-child) > .dropdown-toggle,
.btn-group-vertical > .btn-group:first-child:not(:last-child) > .pattern-relateditems-container .dropdown-toggle,
.btn-group-vertical > .btn-group:first-child:not(:last-child) > .pattern-pickadate-wrapper .btn:last-child,
.btn-group-vertical > .btn-group:first-child:not(:last-child) > .pattern-pickadate-wrapper .pattern-relateditems-container .btn:last-child,
.btn-group-vertical > .btn-group:first-child:not(:last-child) > .pattern-relateditems-container .pattern-pickadate-wrapper .btn:last-child {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}
/* line 195, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group-vertical > .btn-group:last-child:not(:first-child) > .pattern-relateditems-container .btn:first-child,
.btn-group-vertical > .pattern-relateditems-container .btn-group:last-child:not(:first-child) > .btn:first-child,
.btn-group-vertical > .btn-group:last-child:not(:first-child) > .pattern-pickadate-wrapper .btn:first-child,
.btn-group-vertical > .btn-group:last-child:not(:first-child) > .pattern-pickadate-wrapper .pattern-relateditems-container .btn:first-child,
.btn-group-vertical > .btn-group:last-child:not(:first-child) > .pattern-relateditems-container .pattern-pickadate-wrapper .btn:first-child {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}
/* line 208, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group-justified > .pattern-relateditems-container .btn,
.btn-group-justified > .pattern-relateditems-container .btn-group,
.btn-group-justified > .pattern-pickadate-wrapper .btn,
.btn-group-justified > .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.btn-group-justified > .pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  display: table-cell;
  float: none;
  width: 1%;
}
/* line 214, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group-justified > .btn-group .pattern-relateditems-container .btn,
.btn-group-justified > .pattern-relateditems-container .btn-group .btn,
.btn-group-justified > .btn-group .pattern-pickadate-wrapper .btn,
.btn-group-justified > .btn-group .pattern-pickadate-wrapper .pattern-relateditems-container .btn,
.btn-group-justified > .btn-group .pattern-relateditems-container .pattern-pickadate-wrapper .btn {
  width: 100%;
}
/* line 218, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
.btn-group-justified > .pattern-relateditems-container .btn-group .dropdown-menu,
.btn-group-justified > .btn-group .pattern-relateditems-container .dropdown-menu {
  left: auto;
}
/* line 239, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/button-groups.less */
[data-toggle="buttons"] > .pattern-relateditems-container .btn input[type="radio"],
[data-toggle="buttons"] > .btn-group > .pattern-relateditems-container .btn input[type="radio"],
[data-toggle="buttons"] > .pattern-relateditems-container .btn input[type="checkbox"],
[data-toggle="buttons"] > .btn-group > .pattern-relateditems-container .btn input[type="checkbox"],
[data-toggle="buttons"] > .pattern-relateditems-container .btn-group > .btn input[type="radio"],
[data-toggle="buttons"] > .pattern-relateditems-container .btn-group > .btn input[type="checkbox"],
[data-toggle="buttons"] > .pattern-pickadate-wrapper .btn input[type="radio"],
[data-toggle="buttons"] > .btn-group > .pattern-pickadate-wrapper .btn input[type="radio"],
[data-toggle="buttons"] > .pattern-pickadate-wrapper .btn input[type="checkbox"],
[data-toggle="buttons"] > .btn-group > .pattern-pickadate-wrapper .btn input[type="checkbox"],
[data-toggle="buttons"] > .pattern-pickadate-wrapper .pattern-relateditems-container .btn input[type="radio"],
[data-toggle="buttons"] > .btn-group > .pattern-pickadate-wrapper .pattern-relateditems-container .btn input[type="radio"],
[data-toggle="buttons"] > .pattern-pickadate-wrapper .pattern-relateditems-container .btn input[type="checkbox"],
[data-toggle="buttons"] > .btn-group > .pattern-pickadate-wrapper .pattern-relateditems-container .btn input[type="checkbox"],
[data-toggle="buttons"] > .pattern-relateditems-container .pattern-pickadate-wrapper .btn input[type="radio"],
[data-toggle="buttons"] > .btn-group > .pattern-relateditems-container .pattern-pickadate-wrapper .btn input[type="radio"],
[data-toggle="buttons"] > .pattern-relateditems-container .pattern-pickadate-wrapper .btn input[type="checkbox"],
[data-toggle="buttons"] > .btn-group > .pattern-relateditems-container .pattern-pickadate-wrapper .btn input[type="checkbox"] {
  position: absolute;
  clip: rect(0, 0, 0, 0);
  pointer-events: none;
}
/* line 6, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/popovers.less */
.pattern-relateditems-container .popover {
  position: absolute;
  top: 0;
  left: 0;
  z-index: 1060;
  display: none;
  max-width: 276px;
  padding: 1px;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-style: normal;
  font-weight: 400;
  line-height: 1.42857143;
  line-break: auto;
  text-align: left;
  text-align: start;
  text-decoration: none;
  text-shadow: none;
  text-transform: none;
  letter-spacing: normal;
  word-break: normal;
  word-spacing: normal;
  word-wrap: normal;
  white-space: normal;
  font-size: 14px;
  background-color: #ffffff;
  background-clip: padding-box;
  border: 1px solid #cccccc;
  border: 1px solid rgba(0, 0, 0, 0.2);
  border-radius: 6px;
  -webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
}
/* line 26, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/popovers.less */
.pattern-relateditems-container .popover.top {
  margin-top: -10px;
}
/* line 27, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/popovers.less */
.pattern-relateditems-container .popover.right {
  margin-left: 10px;
}
/* line 28, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/popovers.less */
.pattern-relateditems-container .popover.bottom {
  margin-top: 10px;
}
/* line 29, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/popovers.less */
.pattern-relateditems-container .popover.left {
  margin-left: -10px;
}
/* line 33, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/popovers.less */
.pattern-relateditems-container .popover > .arrow,
.popover > .pattern-relateditems-container .arrow {
  border-width: 11px;
}
/* line 36, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/popovers.less */
.pattern-relateditems-container .popover > .arrow,
.pattern-relateditems-container .popover > .arrow:after,
.popover > .pattern-relateditems-container .arrow,
.popover > .pattern-relateditems-container .arrow:after {
  position: absolute;
  display: block;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid;
}
/* line 46, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/popovers.less */
.pattern-relateditems-container .popover > .arrow:after,
.popover > .pattern-relateditems-container .arrow:after {
  content: "";
  border-width: 10px;
}
/* line 52, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/popovers.less */
.pattern-relateditems-container .popover.top > .arrow,
.popover.top > .pattern-relateditems-container .arrow {
  bottom: -11px;
  left: 50%;
  margin-left: -11px;
  border-top-color: #999999;
  border-top-color: rgba(0, 0, 0, 0.25);
  border-bottom-width: 0;
}
/* line 59, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/popovers.less */
.pattern-relateditems-container .popover.top > .arrow:after,
.popover.top > .pattern-relateditems-container .arrow:after {
  bottom: 1px;
  margin-left: -10px;
  content: " ";
  border-top-color: #ffffff;
  border-bottom-width: 0;
}
/* line 67, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/popovers.less */
.pattern-relateditems-container .popover.right > .arrow,
.popover.right > .pattern-relateditems-container .arrow {
  top: 50%;
  left: -11px;
  margin-top: -11px;
  border-right-color: #999999;
  border-right-color: rgba(0, 0, 0, 0.25);
  border-left-width: 0;
}
/* line 74, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/popovers.less */
.pattern-relateditems-container .popover.right > .arrow:after,
.popover.right > .pattern-relateditems-container .arrow:after {
  bottom: -10px;
  left: 1px;
  content: " ";
  border-right-color: #ffffff;
  border-left-width: 0;
}
/* line 82, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/popovers.less */
.pattern-relateditems-container .popover.bottom > .arrow,
.popover.bottom > .pattern-relateditems-container .arrow {
  top: -11px;
  left: 50%;
  margin-left: -11px;
  border-top-width: 0;
  border-bottom-color: #999999;
  border-bottom-color: rgba(0, 0, 0, 0.25);
}
/* line 89, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/popovers.less */
.pattern-relateditems-container .popover.bottom > .arrow:after,
.popover.bottom > .pattern-relateditems-container .arrow:after {
  top: 1px;
  margin-left: -10px;
  content: " ";
  border-top-width: 0;
  border-bottom-color: #ffffff;
}
/* line 98, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/popovers.less */
.pattern-relateditems-container .popover.left > .arrow,
.popover.left > .pattern-relateditems-container .arrow {
  top: 50%;
  right: -11px;
  margin-top: -11px;
  border-right-width: 0;
  border-left-color: #999999;
  border-left-color: rgba(0, 0, 0, 0.25);
}
/* line 105, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/popovers.less */
.pattern-relateditems-container .popover.left > .arrow:after,
.popover.left > .pattern-relateditems-container .arrow:after {
  right: 1px;
  bottom: -10px;
  content: " ";
  border-right-width: 0;
  border-left-color: #ffffff;
}
/* line 115, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/popovers.less */
.pattern-relateditems-container .popover-title {
  padding: 8px 14px;
  margin: 0;
  font-size: 14px;
  background-color: #f7f7f7;
  border-bottom: 1px solid #ebebeb;
  border-radius: 5px 5px 0 0;
}
/* line 124, http://localhost:8080/ideabox/++plone++static/components//bootstrap/less/popovers.less */
.pattern-relateditems-container .popover-content {
  padding: 9px 14px;
}
/* line 1, http://localhost:8080/ideabox/++resource++mockupless//popover.less */
.pattern-relateditems-container .popover {
  min-width: 111px;
  max-width: 500px;
}
/* line 5, http://localhost:8080/ideabox/++resource++mockupless//popover.less */
.pattern-relateditems-container .popover .popover-title,
.popover .pattern-relateditems-container .popover-title {
  padding-bottom: 0;
}
/* line 8, http://localhost:8080/ideabox/++resource++mockupless//popover.less */
.pattern-relateditems-container .popover .popover-title input,
.popover .pattern-relateditems-container .popover-title input {
  margin-bottom: 0;
}
/* line 12, http://localhost:8080/ideabox/++resource++mockupless//popover.less */
.pattern-relateditems-container .popover.active {
  display: block;
}
/* specifying (less) here forces it to be included inline, processed as less and minified */
/*
Version: 3.5.4 Timestamp: Sun Aug 30 13:30:32 EDT 2015
*/
/* line 4, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container {
  margin: 0;
  position: relative;
  display: inline-block;
  vertical-align: middle;
}
/* line 11, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container,
.select2-drop,
.select2-search,
.select2-search input {
  /*
    Force border-box so that % widths fit the parent
    container without overlap because of margin/padding.
    More Info : http://www.quirksmode.org/css/box.html
  */
  -webkit-box-sizing: border-box;
  /* webkit */
  -moz-box-sizing: border-box;
  /* firefox */
  box-sizing: border-box;
  /* css3 */
}
/* line 25, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container .select2-choice {
  display: block;
  height: 26px;
  padding: 0 0 0 8px;
  overflow: hidden;
  position: relative;
  border: 1px solid #aaa;
  white-space: nowrap;
  line-height: 26px;
  color: #444;
  text-decoration: none;
  border-radius: 4px;
  background-clip: padding-box;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  background-color: #fff;
  background-image: -webkit-gradient(linear, left bottom, left top, color-stop(0, #eeeeee), color-stop(0.5, #ffffff));
  background-image: -webkit-linear-gradient(center bottom, #eeeeee 0%, #ffffff 50%);
  background-image: -moz-linear-gradient(center bottom, #eeeeee 0%, #ffffff 50%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#eeeeee', GradientType=0);
  background-image: linear-gradient(to top, #eeeeee 0%, #ffffff 50%);
}
/* line 56, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
html[dir="rtl"] .select2-container .select2-choice {
  padding: 0 8px 0 0;
}
/* line 60, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container.select2-drop-above .select2-choice {
  border-bottom-color: #aaa;
  border-radius: 0 0 4px 4px;
  background-image: -webkit-gradient(linear, left bottom, left top, color-stop(0, #eeeeee), color-stop(0.9, #ffffff));
  background-image: -webkit-linear-gradient(center bottom, #eeeeee 0%, #ffffff 90%);
  background-image: -moz-linear-gradient(center bottom, #eeeeee 0%, #ffffff 90%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#eeeeee', GradientType=0);
  background-image: linear-gradient(to bottom, #eeeeee 0%, #ffffff 90%);
}
/* line 72, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container.select2-allowclear .select2-choice .select2-chosen {
  margin-right: 42px;
}
/* line 76, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container .select2-choice > .select2-chosen {
  margin-right: 26px;
  display: block;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  float: none;
  width: auto;
}
/* line 88, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
html[dir="rtl"] .select2-container .select2-choice > .select2-chosen {
  margin-left: 26px;
  margin-right: 0;
}
/* line 93, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container .select2-choice abbr {
  display: none;
  width: 12px;
  height: 12px;
  position: absolute;
  right: 24px;
  top: 8px;
  font-size: 1px;
  text-decoration: none;
  border: 0;
  background: url('components/select2/select2.png') right top no-repeat;
  cursor: pointer;
  outline: 0;
}
/* line 110, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container.select2-allowclear .select2-choice abbr {
  display: inline-block;
}
/* line 114, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container .select2-choice abbr:hover {
  background-position: right -11px;
  cursor: pointer;
}
/* line 119, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-drop-mask {
  border: 0;
  margin: 0;
  padding: 0;
  position: fixed;
  left: 0;
  top: 0;
  min-height: 100%;
  min-width: 100%;
  height: auto;
  width: auto;
  opacity: 0;
  z-index: 9998;
  /* styles required for IE to work */
  background-color: #fff;
  filter: alpha(opacity=0);
}
/* line 137, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-drop {
  width: 100%;
  margin-top: -1px;
  position: absolute;
  z-index: 9999;
  top: 100%;
  background: #fff;
  color: #000;
  border: 1px solid #aaa;
  border-top: 0;
  border-radius: 0 0 4px 4px;
  -webkit-box-shadow: 0 4px 5px rgba(0, 0, 0, 0.15);
  box-shadow: 0 4px 5px rgba(0, 0, 0, 0.15);
}
/* line 155, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-drop.select2-drop-above {
  margin-top: 1px;
  border-top: 1px solid #aaa;
  border-bottom: 0;
  border-radius: 4px 4px 0 0;
  -webkit-box-shadow: 0 -4px 5px rgba(0, 0, 0, 0.15);
  box-shadow: 0 -4px 5px rgba(0, 0, 0, 0.15);
}
/* line 166, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-drop-active {
  border: 1px solid #5897fb;
  border-top: none;
}
/* line 171, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-drop.select2-drop-above.select2-drop-active {
  border-top: 1px solid #5897fb;
}
/* line 175, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-drop-auto-width {
  border-top: 1px solid #aaa;
  width: auto;
}
/* line 180, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container .select2-choice .select2-arrow {
  display: inline-block;
  width: 18px;
  height: 100%;
  position: absolute;
  right: 0;
  top: 0;
  border-left: 1px solid #aaa;
  border-radius: 0 4px 4px 0;
  background-clip: padding-box;
  background: #ccc;
  background-image: -webkit-gradient(linear, left bottom, left top, color-stop(0, #cccccc), color-stop(0.6, #eeeeee));
  background-image: -webkit-linear-gradient(center bottom, #cccccc 0%, #eeeeee 60%);
  background-image: -moz-linear-gradient(center bottom, #cccccc 0%, #eeeeee 60%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#eeeeee', endColorstr='#cccccc', GradientType=0);
  background-image: linear-gradient(to top, #cccccc 0%, #eeeeee 60%);
}
/* line 201, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
html[dir="rtl"] .select2-container .select2-choice .select2-arrow {
  left: 0;
  right: auto;
  border-left: none;
  border-right: 1px solid #aaa;
  border-radius: 4px 0 0 4px;
}
/* line 210, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container .select2-choice .select2-arrow b {
  display: block;
  width: 100%;
  height: 100%;
  background: url('components/select2/select2.png') no-repeat 0 1px;
}
/* line 217, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
html[dir="rtl"] .select2-container .select2-choice .select2-arrow b {
  background-position: 2px 1px;
}
/* line 221, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-search {
  display: inline-block;
  width: 100%;
  min-height: 26px;
  margin: 0;
  padding: 4px 4px 0 4px;
  position: relative;
  z-index: 10000;
  white-space: nowrap;
}
/* line 234, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-search input {
  width: 100%;
  height: auto !important;
  min-height: 26px;
  padding: 4px 20px 4px 5px;
  margin: 0;
  outline: 0;
  font-family: sans-serif;
  font-size: 1em;
  border: 1px solid #aaa;
  border-radius: 0;
  -webkit-box-shadow: none;
  box-shadow: none;
  background: #ffffff url('components/select2/select2.png') no-repeat 100% -22px;
  background: url('components/select2/select2.png') no-repeat 100% -22px, -webkit-gradient(linear, left bottom, left top, color-stop(0.85, #ffffff), color-stop(0.99, #eeeeee));
  background: url('components/select2/select2.png') no-repeat 100% -22px, -webkit-linear-gradient(center bottom, #ffffff 85%, #eeeeee 99%);
  background: url('components/select2/select2.png') no-repeat 100% -22px, -moz-linear-gradient(center bottom, #ffffff 85%, #eeeeee 99%);
  background: url('components/select2/select2.png') no-repeat 100% -22px, linear-gradient(to bottom, #ffffff 85%, #eeeeee 99%) 0 0;
}
/* line 258, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
html[dir="rtl"] .select2-search input {
  padding: 4px 5px 4px 20px;
  background: #ffffff url('components/select2/select2.png') no-repeat -37px -22px;
  background: url('components/select2/select2.png') no-repeat -37px -22px, -webkit-gradient(linear, left bottom, left top, color-stop(0.85, #ffffff), color-stop(0.99, #eeeeee));
  background: url('components/select2/select2.png') no-repeat -37px -22px, -webkit-linear-gradient(center bottom, #ffffff 85%, #eeeeee 99%);
  background: url('components/select2/select2.png') no-repeat -37px -22px, -moz-linear-gradient(center bottom, #ffffff 85%, #eeeeee 99%);
  background: url('components/select2/select2.png') no-repeat -37px -22px, linear-gradient(to bottom, #ffffff 85%, #eeeeee 99%) 0 0;
}
/* line 268, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-search input.select2-active {
  background: #ffffff url('components/select2/select2-spinner.gif') no-repeat 100%;
  background: url('components/select2/select2-spinner.gif') no-repeat 100%, -webkit-gradient(linear, left bottom, left top, color-stop(0.85, #ffffff), color-stop(0.99, #eeeeee));
  background: url('components/select2/select2-spinner.gif') no-repeat 100%, -webkit-linear-gradient(center bottom, #ffffff 85%, #eeeeee 99%);
  background: url('components/select2/select2-spinner.gif') no-repeat 100%, -moz-linear-gradient(center bottom, #ffffff 85%, #eeeeee 99%);
  background: url('components/select2/select2-spinner.gif') no-repeat 100%, linear-gradient(to bottom, #ffffff 85%, #eeeeee 99%) 0 0;
}
/* line 276, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container-active .select2-choice,
.select2-container-active .select2-choices {
  border: 1px solid #5897fb;
  outline: none;
  -webkit-box-shadow: 0 0 5px rgba(0, 0, 0, 0.3);
  box-shadow: 0 0 5px rgba(0, 0, 0, 0.3);
}
/* line 285, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-dropdown-open .select2-choice {
  border-bottom-color: transparent;
  -webkit-box-shadow: 0 1px 0 #fff inset;
  box-shadow: 0 1px 0 #fff inset;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
  background-color: #eee;
  background-image: -webkit-gradient(linear, left bottom, left top, color-stop(0, #ffffff), color-stop(0.5, #eeeeee));
  background-image: -webkit-linear-gradient(center bottom, #ffffff 0%, #eeeeee 50%);
  background-image: -moz-linear-gradient(center bottom, #ffffff 0%, #eeeeee 50%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#eeeeee', endColorstr='#ffffff', GradientType=0);
  background-image: linear-gradient(to top, #ffffff 0%, #eeeeee 50%);
}
/* line 301, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-dropdown-open.select2-drop-above .select2-choice,
.select2-dropdown-open.select2-drop-above .select2-choices {
  border: 1px solid #5897fb;
  border-top-color: transparent;
  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0, #ffffff), color-stop(0.5, #eeeeee));
  background-image: -webkit-linear-gradient(center top, #ffffff 0%, #eeeeee 50%);
  background-image: -moz-linear-gradient(center top, #ffffff 0%, #eeeeee 50%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#eeeeee', endColorstr='#ffffff', GradientType=0);
  background-image: linear-gradient(to bottom, #ffffff 0%, #eeeeee 50%);
}
/* line 313, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-dropdown-open .select2-choice .select2-arrow {
  background: transparent;
  border-left: none;
  filter: none;
}
/* line 318, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
html[dir="rtl"] .select2-dropdown-open .select2-choice .select2-arrow {
  border-right: none;
}
/* line 322, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-dropdown-open .select2-choice .select2-arrow b {
  background-position: -18px 1px;
}
/* line 326, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
html[dir="rtl"] .select2-dropdown-open .select2-choice .select2-arrow b {
  background-position: -16px 1px;
}
/* line 330, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-hidden-accessible {
  border: 0;
  clip: rect(0 0 0 0);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px;
}
/* results */
/* line 342, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results {
  max-height: 200px;
  padding: 0 0 0 4px;
  margin: 4px 4px 4px 0;
  position: relative;
  overflow-x: hidden;
  overflow-y: auto;
  -webkit-tap-highlight-color: rgba(0, 0, 0, 0);
}
/* line 352, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
html[dir="rtl"] .select2-results {
  padding: 0 4px 0 0;
  margin: 4px 0 4px 4px;
}
/* line 357, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results ul.select2-result-sub {
  margin: 0;
  padding-left: 0;
}
/* line 362, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results li {
  list-style: none;
  display: list-item;
  background-image: none;
}
/* line 368, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results li.select2-result-with-children > .select2-result-label {
  font-weight: bold;
}
/* line 372, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results .select2-result-label {
  padding: 3px 7px 4px;
  margin: 0;
  cursor: pointer;
  min-height: 1em;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
/* line 386, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results-dept-1 .select2-result-label {
  padding-left: 20px;
}
/* line 387, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results-dept-2 .select2-result-label {
  padding-left: 40px;
}
/* line 388, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results-dept-3 .select2-result-label {
  padding-left: 60px;
}
/* line 389, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results-dept-4 .select2-result-label {
  padding-left: 80px;
}
/* line 390, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results-dept-5 .select2-result-label {
  padding-left: 100px;
}
/* line 391, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results-dept-6 .select2-result-label {
  padding-left: 110px;
}
/* line 392, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results-dept-7 .select2-result-label {
  padding-left: 120px;
}
/* line 394, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results .select2-highlighted {
  background: #3875d7;
  color: #fff;
}
/* line 399, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results li em {
  background: #feffde;
  font-style: normal;
}
/* line 404, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results .select2-highlighted em {
  background: transparent;
}
/* line 408, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results .select2-highlighted ul {
  background: #fff;
  color: #000;
}
/* line 413, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results .select2-no-results,
.select2-results .select2-searching,
.select2-results .select2-ajax-error,
.select2-results .select2-selection-limit {
  background: #f4f4f4;
  display: list-item;
  padding-left: 5px;
}
/*
disabled look for disabled choices in the results dropdown
*/
/* line 425, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results .select2-disabled.select2-highlighted {
  color: #666;
  background: #f4f4f4;
  display: list-item;
  cursor: default;
}
/* line 431, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results .select2-disabled {
  background: #f4f4f4;
  display: list-item;
  cursor: default;
}
/* line 437, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results .select2-selected {
  display: none;
}
/* line 441, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-more-results.select2-active {
  background: #f4f4f4 url('components/select2/select2-spinner.gif') no-repeat 100%;
}
/* line 445, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-results .select2-ajax-error {
  background: rgba(255, 50, 50, 0.2);
}
/* line 449, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-more-results {
  background: #f4f4f4;
  display: list-item;
}
/* disabled styles */
/* line 456, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container.select2-container-disabled .select2-choice {
  background-color: #f4f4f4;
  background-image: none;
  border: 1px solid #ddd;
  cursor: default;
}
/* line 463, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container.select2-container-disabled .select2-choice .select2-arrow {
  background-color: #f4f4f4;
  background-image: none;
  border-left: 0;
}
/* line 469, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container.select2-container-disabled .select2-choice abbr {
  display: none;
}
/* multiselect */
/* line 476, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container-multi .select2-choices {
  height: auto !important;
  height: 1%;
  margin: 0;
  padding: 0 5px 0 0;
  position: relative;
  border: 1px solid #aaa;
  cursor: text;
  overflow: hidden;
  background-color: #fff;
  background-image: -webkit-gradient(linear, 0% 0%, 0% 100%, color-stop(1%, #eeeeee), color-stop(15%, #ffffff));
  background-image: -webkit-linear-gradient(top, #eeeeee 1%, #ffffff 15%);
  background-image: -moz-linear-gradient(top, #eeeeee 1%, #ffffff 15%);
  background-image: linear-gradient(to bottom, #eeeeee 1%, #ffffff 15%);
}
/* line 494, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
html[dir="rtl"] .select2-container-multi .select2-choices {
  padding: 0 0 0 5px;
}
/* line 498, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-locked {
  padding: 3px 5px 3px 5px !important;
}
/* line 502, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container-multi .select2-choices {
  min-height: 26px;
}
/* line 506, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container-multi.select2-container-active .select2-choices {
  border: 1px solid #5897fb;
  outline: none;
  -webkit-box-shadow: 0 0 5px rgba(0, 0, 0, 0.3);
  box-shadow: 0 0 5px rgba(0, 0, 0, 0.3);
}
/* line 513, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container-multi .select2-choices li {
  float: left;
  list-style: none;
}
/* line 517, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
html[dir="rtl"] .select2-container-multi .select2-choices li {
  float: right;
}
/* line 521, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container-multi .select2-choices .select2-search-field {
  margin: 0;
  padding: 0;
  white-space: nowrap;
}
/* line 527, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container-multi .select2-choices .select2-search-field input {
  padding: 5px;
  margin: 1px 0;
  font-family: sans-serif;
  font-size: 100%;
  color: #666;
  outline: 0;
  border: 0;
  -webkit-box-shadow: none;
  box-shadow: none;
  background: transparent !important;
}
/* line 541, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container-multi .select2-choices .select2-search-field input.select2-active {
  background: #ffffff url('components/select2/select2-spinner.gif') no-repeat 100% !important;
}
/* line 545, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-default {
  color: #999 !important;
}
/* line 549, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container-multi .select2-choices .select2-search-choice {
  padding: 3px 5px 3px 18px;
  margin: 3px 0 3px 5px;
  position: relative;
  line-height: 13px;
  color: #333;
  cursor: default;
  border: 1px solid #aaaaaa;
  border-radius: 3px;
  -webkit-box-shadow: 0 0 2px #ffffff inset, 0 1px 0 rgba(0, 0, 0, 0.05);
  box-shadow: 0 0 2px #ffffff inset, 0 1px 0 rgba(0, 0, 0, 0.05);
  background-clip: padding-box;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  background-color: #e4e4e4;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#eeeeee', endColorstr='#f4f4f4', GradientType=0);
  background-image: -webkit-gradient(linear, 0% 0%, 0% 100%, color-stop(20%, #f4f4f4), color-stop(50%, #f0f0f0), color-stop(52%, #e8e8e8), color-stop(100%, #eeeeee));
  background-image: -webkit-linear-gradient(top, #f4f4f4 20%, #f0f0f0 50%, #e8e8e8 52%, #eeeeee 100%);
  background-image: -moz-linear-gradient(top, #f4f4f4 20%, #f0f0f0 50%, #e8e8e8 52%, #eeeeee 100%);
  background-image: linear-gradient(to bottom, #f4f4f4 20%, #f0f0f0 50%, #e8e8e8 52%, #eeeeee 100%);
}
/* line 579, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
html[dir="rtl"] .select2-container-multi .select2-choices .select2-search-choice {
  margin: 3px 5px 3px 0;
  padding: 3px 18px 3px 5px;
}
/* line 584, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container-multi .select2-choices .select2-search-choice .select2-chosen {
  cursor: default;
}
/* line 587, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container-multi .select2-choices .select2-search-choice-focus {
  background: #d4d4d4;
}
/* line 591, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-search-choice-close {
  display: block;
  width: 12px;
  height: 13px;
  position: absolute;
  right: 3px;
  top: 4px;
  font-size: 1px;
  outline: none;
  background: url('components/select2/select2.png') right top no-repeat;
}
/* line 603, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
html[dir="rtl"] .select2-search-choice-close {
  right: auto;
  left: 3px;
}
/* line 608, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container-multi .select2-search-choice-close {
  left: 3px;
}
/* line 612, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
html[dir="rtl"] .select2-container-multi .select2-search-choice-close {
  left: auto;
  right: 2px;
}
/* line 617, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container-multi .select2-choices .select2-search-choice .select2-search-choice-close:hover {
  background-position: right -11px;
}
/* line 620, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container-multi .select2-choices .select2-search-choice-focus .select2-search-choice-close {
  background-position: right -11px;
}
/* disabled styles */
/* line 625, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container-multi.select2-container-disabled .select2-choices {
  background-color: #f4f4f4;
  background-image: none;
  border: 1px solid #ddd;
  cursor: default;
}
/* line 632, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice {
  padding: 3px 5px 3px 5px;
  border: 1px solid #ddd;
  background-image: none;
  background-color: #f4f4f4;
}
/* line 639, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close {
  display: none;
  background: none;
}
/* end multiselect */
/* line 645, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-result-selectable .select2-match,
.select2-result-unselectable .select2-match {
  text-decoration: underline;
}
/* line 650, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-offscreen,
.select2-offscreen:focus {
  clip: rect(0 0 0 0) !important;
  width: 1px !important;
  height: 1px !important;
  border: 0 !important;
  margin: 0 !important;
  padding: 0 !important;
  overflow: hidden !important;
  position: absolute !important;
  outline: 0 !important;
  left: 0px !important;
  top: 0px !important;
}
/* line 664, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-display-none {
  display: none;
}
/* line 668, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
.select2-measure-scrollbar {
  position: absolute;
  top: -10000px;
  left: -10000px;
  width: 100px;
  height: 100px;
  overflow: scroll;
}
/* Retina-ize icons */
@media only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 2dppx) {
  /* line 680, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
  .select2-search input,
  .select2-search-choice-close,
  .select2-container .select2-choice abbr,
  .select2-container .select2-choice .select2-arrow b {
    background-image: url('components/select2/select2x2.png') !important;
    background-repeat: no-repeat !important;
    background-size: 60px 40px !important;
  }
  /* line 689, http://localhost:8080/ideabox/++plone++static/components//select2/select2.css */
  .select2-search input {
    background-position: 100% -21px !important;
  }
}
/* line 4, http://localhost:8080/ideabox/++resource++mockup//select2/pattern.select2.less */
.select2-container {
  margin-bottom: 1em;
}
/* line 10, http://localhost:8080/ideabox/++resource++mockup//select2/pattern.select2.less */
.select2-container-multi .select2-choices .select2-choice-dragging {
  border-color: #FF0000;
}
/* line 14, http://localhost:8080/ideabox/++resource++mockup//select2/pattern.select2.less */
.select2-container-multi .select2-choices .select2-search-field input {
  height: inherit;
  padding: 2px 1px 1px 8px;
}
/* line 23, http://localhost:8080/ideabox/++resource++mockup//select2/pattern.select2.less */
.select2-container-multi .select2-orderable .select2-search-choice,
.select2-container-multi .select2-orderable .select2-search-choice span {
  cursor: move;
}
/* line 33, http://localhost:8080/ideabox/++resource++mockup//select2/pattern.select2.less */
#content-core .select2-search-choice-close {
  border-bottom: 0;
}
/* line 38, http://localhost:8080/ideabox/++resource++mockup//select2/pattern.select2.less */
.pat-select2 {
  min-width: 50%;
}
/* line 16, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-container {
  position: relative;
  display: inline-block;
}
/* line 59, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-container .toolbar {
  background-color: #d8d8d8;
  display: inline-block;
  width: 100%;
}
/* line 68, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-container .toolbar .mode-selector {
  display: inline-block;
  vertical-align: middle;
}
/* line 73, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-container .toolbar .path-wrapper {
  display: inline-block;
  margin: 0.5em;
  vertical-align: middle;
}
/* line 79, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-container .toolbar .controls {
  display: inline-block;
  vertical-align: middle;
}
/* line 85, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-container .favorites .recentlyUsed {
  position: relative;
}
/* line 90, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-container .dropdown-menu,
.pattern-relateditems-container .pattern-relateditems-container .dropdown-menu {
  padding: 1em 0;
}
/* line 93, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-container .dropdown-menu a,
.pattern-relateditems-container .pattern-relateditems-container .dropdown-menu a {
  cursor: pointer;
  display: block;
  padding: 0.5em 1em;
}
/* line 98, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-container .dropdown-menu a,
.pattern-relateditems-container .dropdown-menu a:hover,
.pattern-relateditems-container .pattern-relateditems-container .dropdown-menu a,
.pattern-relateditems-container .pattern-relateditems-container .dropdown-menu a:hover {
  border-bottom: 0;
  text-decoration: none;
}
/* line 104, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-container .dropdown-menu a:hover,
.pattern-relateditems-container .pattern-relateditems-container .dropdown-menu a:hover {
  background: rgba(0, 0, 0, 0.1);
}
/* line 108, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-container .dropdown-menu a:last-child,
.pattern-relateditems-container .pattern-relateditems-container .dropdown-menu a:last-child {
  margin-bottom: 0;
}
/* line 113, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-container .dropdown-menu .pattern-relateditems-recentlyused-select,
.pattern-relateditems-container .pattern-relateditems-container .dropdown-menu .pattern-relateditems-recentlyused-select {
  display: flex;
  justify-content: space-between;
  padding: 3px;
}
/* line 118, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-container .dropdown-menu .pattern-relateditems-recentlyused-select .pattern-relateditems-recentlyused-info,
.pattern-relateditems-container .pattern-relateditems-container .dropdown-menu .pattern-relateditems-recentlyused-select .pattern-relateditems-recentlyused-info {
  flex-grow: 2;
  hyphens: auto;
  white-space: normal;
}
/* line 124, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-container .dropdown-menu .pattern-relateditems-recentlyused-select .pattern-relateditems-recentlyused-image,
.pattern-relateditems-container .pattern-relateditems-container .dropdown-menu .pattern-relateditems-recentlyused-select .pattern-relateditems-recentlyused-image {
  flex: 0 0 auto;
}
/* line 130, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-container .toolbar .dropdown-menu,
.pattern-relateditems-container .toolbar .pattern-relateditems-container .dropdown-menu {
  min-width: 310px;
}
/* line 134, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-container .pattern-relateditems-result-info {
  flex-grow: 2;
  margin: 0.4em 0.4em 0.4em 1.5em;
  hyphens: auto;
}
/* line 140, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-container .pattern-relateditems-item {
  display: flex;
}
/* line 146, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-dropdown .select2-results {
  background-color: #fff;
  max-height: 350px;
}
/* line 150, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-dropdown .select2-results .select2-result {
  background-color: transparent;
}
/* line 153, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-dropdown .select2-results .select2-result:nth-child(odd) {
  background-color: #f7f7f7;
}
/* line 157, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-dropdown .select2-results .select2-result.select2-highlighted {
  border-left: 0.3em solid #007bb3;
  border-right: 0.3em solid #007bb3;
}
/* line 162, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-dropdown .select2-results .select2-result-label {
  padding: 0;
}
/* line 167, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-dropdown .select2-results .select2-selected {
  display: list-item;
}
/* line 173, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-active {
  background-color: #ddd;
  padding: 5px;
}
/* line 178, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-path-label {
  margin-top: 2px;
}
/* line 183, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pat-relateditems .select2-choices {
  align-items: stretch;
  display: flex;
  flex-flow: row wrap;
  justify-content: flex-start;
  padding: 0.2em;
}
/* line 190, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pat-relateditems .select2-choices > li {
  flex: 1 1 100%;
}
/* line 195, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pat-relateditems .select2-choices .select2-search-choice.select2-search-choice-focus {
  border-left: 0.5em solid #286090;
}
/* line 203, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pat-relateditems.select2-container-multi .select2-choices .select2-search-choice {
  background-image: none;
  background-color: #eee;
  margin: 0.2em;
  padding: 0;
}
/* line 211, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pat-relateditems.select2-container-multi .select2-choices .select2-search-choice .select2-search-choice-close {
  left: 0.4rem;
  right: auto;
  text-decoration: none;
  top: 0.4rem;
}
/* line 218, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pat-relateditems.select2-container-multi .select2-choices .select2-search-choice .pattern-relateditems-item-image {
  flex: 0 0 auto;
}
/* line 227, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-result {
  display: flex;
  justify-content: space-between;
  margin-bottom: 0.15em;
}
/* line 233, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-result a:hover {
  text-decoration: none;
}
/* line 238, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-result .pattern-relateditems-result-info {
  padding: 0.4em;
}
/* line 242, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-result .pattern-relateditems-result-browse-wrapper {
  display: flex;
  flex: 2 1 fill;
  justify-content: flex-start;
}
/* line 249, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-result .pattern-relateditems-result-browse-wrapper .pattern-relateditems-result-select:not(.selectable):not(.one-level-up) {
  opacity: 0.6;
}
/* line 255, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-result .pattern-relateditems-result-browse-wrapper .pattern-relateditems-result-browse {
  font-size: 2.1rem;
  line-height: 1.8em;
  margin: 0 0.1em 0 0;
  padding: 0 0.15em 0 0.1em;
}
/* line 261, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-result .pattern-relateditems-result-browse-wrapper .pattern-relateditems-result-browse:hover {
  background-color: #e5e5e5;
}
/* line 265, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-result .pattern-relateditems-result-browse-wrapper .pattern-relateditems-result-browse span {
  vertical-align: middle;
}
/* line 270, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-result.one-level-up {
  background-color: #ddd;
}
/* line 273, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-result.one-level-up .pattern-relateditems-result-browse-wrapper {
  flex-direction: row-reverse;
}
/* line 279, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-item-title,
.pattern-relateditems-result-title {
  font-size: 1.6rem;
  line-height: 1.2;
  padding: 0;
}
/* line 286, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-item-title[class*="contenttype-"]::before,
.pattern-relateditems-result-title[class*="contenttype-"]::before {
  font-size: 1.46rem;
  height: 25px;
  vertical-align: middle;
  width: 14px;
}
/* line 295, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-result-path {
  margin-top: -5px;
}
/* line 305, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-result-image img,
.pattern-relateditems-recentlyused-image img,
.pattern-relateditems-item-image img,
#content-core .pattern-relateditems-result-image img,
#content-core .pattern-relateditems-recentlyused-image img,
#content-core .pattern-relateditems-item-image img {
  max-height: 128px;
  max-width: 128px;
}
/* line 314, http://localhost:8080/ideabox/++resource++mockup/relateditems/pattern.relateditems.less */
.pattern-relateditems-recentlyused-path,
.pattern-relateditems-item-path,
.pattern-relateditems-result-path {
  color: #444;
  display: block;
  font-size: 0.8em;
  padding-left: 0.2em;
}
/* ==========================================================================
   $BASE-PICKER
   ========================================================================== */
/**
 * Note: the root picker element should *NOT* be styled more than what’s here.
 */
/* line 7, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.css */
.picker {
  font-size: 16px;
  text-align: left;
  line-height: 1.2;
  color: #000;
  position: absolute;
  z-index: 10000;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  outline: none;
}
/**
 * The picker input element.
 */
/* line 23, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.css */
.picker__input {
  cursor: default;
}
/**
 * When the picker is opened, the input element is “activated”.
 */
/* line 29, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.css */
.picker__input.picker__input--active {
  border-color: #0089ec;
}
/**
 * The holder is the only “scrollable” top-level container element.
 */
/* line 35, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.css */
.picker__holder {
  width: 100%;
  overflow-y: auto;
  -webkit-overflow-scrolling: touch;
}
/*!
 * Classic picker styling for pickadate.js
 * Demo: http://amsul.github.io/pickadate.js
 */
/**
 * Note: the root picker element should *NOT* be styled more than what’s here.
 */
/* line 48, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.css */
.picker {
  width: 100%;
}
/**
 * The holder is the base of the picker.
 */
/* line 54, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.css */
.picker__holder {
  position: absolute;
  background: #fff;
  border: 1px solid #aaaaaa;
  border-top-width: 0;
  border-bottom-width: 0;
  border-radius: 0 0 5px 5px;
  box-sizing: border-box;
  min-width: 176px;
  max-width: 466px;
  max-height: 0;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  filter: alpha(opacity=0);
  -moz-opacity: 0;
  opacity: 0;
  transform: translateY(-1em) perspective(600px) rotateX(10deg);
  transition: transform 0.15s ease-out, opacity 0.15s ease-out, max-height 0s 0.15s, border-width 0s 0.15s;
}
/**
 * The frame and wrap work together to ensure that
 * clicks within the picker don’t reach the holder.
 */
/* line 76, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.css */
.picker__frame {
  padding: 1px;
}
/* line 79, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.css */
.picker__wrap {
  margin: -1px;
}
/**
 * When the picker opens...
 */
/* line 85, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.css */
.picker--opened .picker__holder {
  max-height: 25em;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=100)";
  filter: alpha(opacity=100);
  -moz-opacity: 1;
  opacity: 1;
  border-top-width: 1px;
  border-bottom-width: 1px;
  transform: translateY(0) perspective(600px) rotateX(0);
  transition: transform 0.15s ease-out, opacity 0.15s ease-out, max-height 0s, border-width 0s;
  box-shadow: 0 6px 18px 1px rgba(0, 0, 0, 0.12);
}
/* ==========================================================================
   $BASE-DATE-PICKER
   ========================================================================== */
/**
 * The picker box.
 */
/* line 7, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__box {
  padding: 0 1em;
}
/**
 * The header containing the month and year stuff.
 */
/* line 13, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__header {
  text-align: center;
  position: relative;
  margin-top: .75em;
}
/**
 * The month and year labels.
 */
/* line 21, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__month,
.picker__year {
  font-weight: 500;
  display: inline-block;
  margin-left: .25em;
  margin-right: .25em;
}
/* line 28, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__year {
  color: #999;
  font-size: .8em;
  font-style: italic;
}
/**
 * The month and year selectors.
 */
/* line 36, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__select--month,
.picker__select--year {
  border: 1px solid #b7b7b7;
  height: 2em;
  padding: .5em;
  margin-left: .25em;
  margin-right: .25em;
}
@media (min-width: 24.5em) {
  /* line 45, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
  .picker__select--month,
  .picker__select--year {
    margin-top: -0.5em;
  }
}
/* line 50, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__select--month {
  width: 35%;
}
/* line 53, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__select--year {
  width: 22.5%;
}
/* line 56, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__select--month:focus,
.picker__select--year:focus {
  border-color: #0089ec;
}
/**
 * The month navigation buttons.
 */
/* line 63, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__nav--prev,
.picker__nav--next {
  position: absolute;
  padding: .5em 1.25em;
  width: 1em;
  height: 1em;
  box-sizing: content-box;
  top: -0.25em;
}
@media (min-width: 24.5em) {
  /* line 73, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
  .picker__nav--prev,
  .picker__nav--next {
    top: -0.33em;
  }
}
/* line 78, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__nav--prev {
  left: -1em;
  padding-right: 1.25em;
}
@media (min-width: 24.5em) {
  /* line 83, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
  .picker__nav--prev {
    padding-right: 1.5em;
  }
}
/* line 87, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__nav--next {
  right: -1em;
  padding-left: 1.25em;
}
@media (min-width: 24.5em) {
  /* line 92, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
  .picker__nav--next {
    padding-left: 1.5em;
  }
}
/* line 96, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__nav--prev:before,
.picker__nav--next:before {
  content: " ";
  border-top: .5em solid transparent;
  border-bottom: .5em solid transparent;
  border-right: 0.75em solid #000;
  width: 0;
  height: 0;
  display: block;
  margin: 0 auto;
}
/* line 107, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__nav--next:before {
  border-right: 0;
  border-left: 0.75em solid #000;
}
/* line 111, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__nav--prev:hover,
.picker__nav--next:hover {
  cursor: pointer;
  color: #000;
  background: #b1dcfb;
}
/* line 117, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__nav--disabled,
.picker__nav--disabled:hover,
.picker__nav--disabled:before,
.picker__nav--disabled:before:hover {
  cursor: default;
  background: none;
  border-right-color: #f5f5f5;
  border-left-color: #f5f5f5;
}
/**
 * The calendar table of dates
 */
/* line 129, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__table {
  text-align: center;
  border-collapse: collapse;
  border-spacing: 0;
  table-layout: fixed;
  font-size: inherit;
  width: 100%;
  margin-top: .75em;
  margin-bottom: .5em;
}
@media (min-height: 33.875em) {
  /* line 140, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
  .picker__table {
    margin-bottom: .75em;
  }
}
/* line 144, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__table td {
  margin: 0;
  padding: 0;
}
/**
 * The weekday labels
 */
/* line 151, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__weekday {
  width: 14.285714286%;
  font-size: .75em;
  padding-bottom: .25em;
  color: #999;
  font-weight: 500;
  /* Increase the spacing a tad */
}
@media (min-height: 33.875em) {
  /* line 160, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
  .picker__weekday {
    padding-bottom: .5em;
  }
}
/**
 * The days on the calendar
 */
/* line 167, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__day {
  padding: .3125em 0;
  font-weight: 200;
  border: 1px solid transparent;
}
/* line 172, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__day--today {
  position: relative;
}
/* line 175, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__day--today:before {
  content: " ";
  position: absolute;
  top: 2px;
  right: 2px;
  width: 0;
  height: 0;
  border-top: 0.5em solid #0059bc;
  border-left: .5em solid transparent;
}
/* line 185, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__day--disabled:before {
  border-top-color: #aaa;
}
/* line 188, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__day--outfocus {
  color: #ddd;
}
/* line 191, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__day--infocus:hover,
.picker__day--outfocus:hover {
  cursor: pointer;
  color: #000;
  background: #b1dcfb;
}
/* line 197, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__day--highlighted {
  border-color: #0089ec;
}
/* line 200, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__day--highlighted:hover,
.picker--focused .picker__day--highlighted {
  cursor: pointer;
  color: #000;
  background: #b1dcfb;
}
/* line 206, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__day--selected,
.picker__day--selected:hover,
.picker--focused .picker__day--selected {
  background: #0089ec;
  color: #fff;
}
/* line 212, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__day--disabled,
.picker__day--disabled:hover,
.picker--focused .picker__day--disabled {
  background: #f5f5f5;
  border-color: #f5f5f5;
  color: #ddd;
  cursor: default;
}
/* line 220, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__day--highlighted.picker__day--disabled,
.picker__day--highlighted.picker__day--disabled:hover {
  background: #bbb;
}
/**
 * The footer containing the "today", "clear", and "close" buttons.
 */
/* line 227, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__footer {
  text-align: center;
}
/* line 230, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__button--today,
.picker__button--clear,
.picker__button--close {
  border: 1px solid #fff;
  background: #fff;
  font-size: .8em;
  padding: .66em 0;
  font-weight: bold;
  width: 33%;
  display: inline-block;
  vertical-align: bottom;
}
/* line 242, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__button--today:hover,
.picker__button--clear:hover,
.picker__button--close:hover {
  cursor: pointer;
  color: #000;
  background: #b1dcfb;
  border-bottom-color: #b1dcfb;
}
/* line 250, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__button--today:focus,
.picker__button--clear:focus,
.picker__button--close:focus {
  background: #b1dcfb;
  border-color: #0089ec;
  outline: none;
}
/* line 257, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__button--today:before,
.picker__button--clear:before,
.picker__button--close:before {
  position: relative;
  display: inline-block;
  height: 0;
}
/* line 264, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__button--today:before,
.picker__button--clear:before {
  content: " ";
  margin-right: .45em;
}
/* line 269, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__button--today:before {
  top: -0.05em;
  width: 0;
  border-top: 0.66em solid #0059bc;
  border-left: .66em solid transparent;
}
/* line 275, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__button--clear:before {
  top: -0.25em;
  width: .66em;
  border-top: 3px solid #e20;
}
/* line 280, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__button--close:before {
  content: "\D7";
  top: -0.1em;
  vertical-align: top;
  font-size: 1.1em;
  margin-right: .35em;
  color: #777;
}
/* line 288, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__button--today[disabled],
.picker__button--today[disabled]:hover {
  background: #f5f5f5;
  border-color: #f5f5f5;
  color: #ddd;
  cursor: default;
}
/* line 295, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.date.css */
.picker__button--today[disabled]:before {
  border-top-color: #aaa;
}
/* ==========================================================================
   $BASE-TIME-PICKER
   ========================================================================== */
/**
 * The list of times.
 */
/* line 7, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.time.css */
.picker__list {
  list-style: none;
  padding: 0.75em 0 4.2em;
  margin: 0;
}
/**
 * The times on the clock.
 */
/* line 15, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.time.css */
.picker__list-item {
  border-bottom: 1px solid #ddd;
  border-top: 1px solid #ddd;
  margin-bottom: -1px;
  position: relative;
  background: #fff;
  padding: .75em 1.25em;
}
@media (min-height: 46.75em) {
  /* line 24, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.time.css */
  .picker__list-item {
    padding: .5em 1em;
  }
}
/* Hovered time */
/* line 29, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.time.css */
.picker__list-item:hover {
  cursor: pointer;
  color: #000;
  background: #b1dcfb;
  border-color: #0089ec;
  z-index: 10;
}
/* Highlighted and hovered/focused time */
/* line 37, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.time.css */
.picker__list-item--highlighted {
  border-color: #0089ec;
  z-index: 10;
}
/* line 41, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.time.css */
.picker__list-item--highlighted:hover,
.picker--focused .picker__list-item--highlighted {
  cursor: pointer;
  color: #000;
  background: #b1dcfb;
}
/* Selected and hovered/focused time */
/* line 48, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.time.css */
.picker__list-item--selected,
.picker__list-item--selected:hover,
.picker--focused .picker__list-item--selected {
  background: #0089ec;
  color: #fff;
  z-index: 10;
}
/* Disabled time */
/* line 56, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.time.css */
.picker__list-item--disabled,
.picker__list-item--disabled:hover,
.picker--focused .picker__list-item--disabled {
  background: #f5f5f5;
  border-color: #f5f5f5;
  color: #ddd;
  cursor: default;
  border-color: #ddd;
  z-index: auto;
}
/**
 * The clear button
 */
/* line 69, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.time.css */
.picker--time .picker__button--clear {
  display: block;
  width: 80%;
  margin: 1em auto 0;
  padding: 1em 1.25em;
  background: none;
  border: 0;
  font-weight: 500;
  font-size: .67em;
  text-align: center;
  text-transform: uppercase;
  color: #666;
}
/* line 82, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.time.css */
.picker--time .picker__button--clear:hover,
.picker--time .picker__button--clear:focus {
  color: #000;
  background: #b1dcfb;
  background: #e20;
  border-color: #e20;
  cursor: pointer;
  color: #fff;
  outline: none;
}
/* line 92, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.time.css */
.picker--time .picker__button--clear:before {
  top: -0.25em;
  color: #666;
  font-size: 1.25em;
  font-weight: bold;
}
/* line 98, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.time.css */
.picker--time .picker__button--clear:hover:before,
.picker--time .picker__button--clear:focus:before {
  color: #fff;
  border-color: #fff;
}
/* ==========================================================================
   $CLASSIC-TIME-PICKER
   ========================================================================== */
/**
 * Note: the root picker element should __NOT__ be styled
 * more than what’s here. Style the `.picker__holder` instead.
 */
/* line 111, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.time.css */
.picker--time {
  min-width: 256px;
  max-width: 320px;
}
/**
 * The holder is the base of the picker.
 */
/* line 118, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.time.css */
.picker--time .picker__holder {
  background: #f2f2f2;
}
@media (min-height: 40.125em) {
  /* line 122, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.time.css */
  .picker--time .picker__holder {
    font-size: .875em;
  }
}
/**
 * The box contains the list of times.
 */
/* line 129, http://localhost:8080/ideabox/++plone++static/components//pickadate/lib/themes/classic.time.css */
.picker--time .picker__box {
  padding: 0;
  position: relative;
}
/* line 8, http://localhost:8080/ideabox/++resource++mockup/pickadate/pattern.pickadate.less */
.pattern-pickadate-wrapper {
  position: relative;
  margin-bottom: 0.5em;
}
/* line 10, http://localhost:8080/ideabox/++resource++mockup/pickadate/pattern.pickadate.less */
.pattern-pickadate-wrapper .btn,
.pattern-pickadate-wrapper .pattern-relateditems-container .btn {
  vertical-align: top;
  margin: 0.2em;
}
/* line 20, http://localhost:8080/ideabox/++resource++mockup/pickadate/pattern.pickadate.less */
.pattern-pickadate-wrapper .picker {
  display: none;
}
/* line 22, http://localhost:8080/ideabox/++resource++mockup/pickadate/pattern.pickadate.less */
.pattern-pickadate-wrapper .picker.picker--opened {
  display: block;
}
/* line 27, http://localhost:8080/ideabox/++resource++mockup/pickadate/pattern.pickadate.less */
.pattern-pickadate-wrapper .pattern-pickadate-date-wrapper {
  display: inline-block;
  vertical-align: middle;
}
/* line 30, http://localhost:8080/ideabox/++resource++mockup/pickadate/pattern.pickadate.less */
.pattern-pickadate-wrapper .pattern-pickadate-date-wrapper .picker__input {
  width: 300px;
  margin: 0.2em;
  text-align: center;
  cursor: context-menu;
}
/* line 36, http://localhost:8080/ideabox/++resource++mockup/pickadate/pattern.pickadate.less */
.pattern-pickadate-wrapper .pattern-pickadate-date-wrapper .picker__holder {
  width: 300px;
  font-size: 12px;
  margin-top: -2px;
}
/* line 44, http://localhost:8080/ideabox/++resource++mockup/pickadate/pattern.pickadate.less */
.pattern-pickadate-wrapper .pattern-pickadate-separator {
  display: inline-block;
  vertical-align: middle;
  margin: 0 0.2em;
}
/* line 50, http://localhost:8080/ideabox/++resource++mockup/pickadate/pattern.pickadate.less */
.pattern-pickadate-wrapper .pattern-pickadate-time-wrapper {
  display: inline-block;
  vertical-align: middle;
}
/* line 53, http://localhost:8080/ideabox/++resource++mockup/pickadate/pattern.pickadate.less */
.pattern-pickadate-wrapper .pattern-pickadate-time-wrapper .picker__input {
  width: 180px;
  margin: 0.2em;
  text-align: center;
  cursor: context-menu;
}
/* line 59, http://localhost:8080/ideabox/++resource++mockup/pickadate/pattern.pickadate.less */
.pattern-pickadate-wrapper .pattern-pickadate-time-wrapper .picker__holder {
  width: 180px;
  font-size: 11px;
  margin-top: -2px;
}
/* line 65, http://localhost:8080/ideabox/++resource++mockup/pickadate/pattern.pickadate.less */
.pattern-pickadate-wrapper .pattern-pickadate-time-wrapper .picker__list-item {
  text-align: center;
}
/* line 70, http://localhost:8080/ideabox/++resource++mockup/pickadate/pattern.pickadate.less */
.pattern-pickadate-wrapper .pattern-pickadate-timezone-wrapper {
  display: inline-block;
  vertical-align: middle;
}
/* line 75, http://localhost:8080/ideabox/++resource++mockup/pickadate/pattern.pickadate.less */
.pattern-pickadate-wrapper .pattern-pickadate-now {
  display: inline-block;
}
/* line 79, http://localhost:8080/ideabox/++resource++mockup/pickadate/pattern.pickadate.less */
.pattern-pickadate-wrapper .pattern-pickadate-clear {
  display: inline-block;
}
/* line 83, http://localhost:8080/ideabox/++resource++mockup/pickadate/pattern.pickadate.less */
.pattern-pickadate-wrapper .picker__select--month,
.pattern-pickadate-wrapper .picker__select--year {
  height: 3em;
}
/* line 87, http://localhost:8080/ideabox/++resource++mockup/pickadate/pattern.pickadate.less */
.pattern-pickadate-wrapper .picker__footer {
  display: none;
}

